a2a

package
v1.0.59 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 17, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type A2aRequestBuilder

A2aRequestBuilder builds and executes requests for operations under \a2a

func NewA2aRequestBuilder

NewA2aRequestBuilder instantiates a new A2aRequestBuilder and sets the default values.

func NewA2aRequestBuilderInternal

func NewA2aRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *A2aRequestBuilder

NewA2aRequestBuilderInternal instantiates a new A2aRequestBuilder and sets the default values.

func (*A2aRequestBuilder) Post

Post send authenticated A2A JSON-RPC requests to Leadping through the API to access supported agent operations and integrate them into your agent workflows. returns a []byte when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*A2aRequestBuilder) ToPostRequestInformation

ToPostRequestInformation send authenticated A2A JSON-RPC requests to Leadping through the API to access supported agent operations and integrate them into your agent workflows. returns a *RequestInformation when successful

func (*A2aRequestBuilder) WithUrl

func (m *A2aRequestBuilder) WithUrl(rawUrl string) *A2aRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *A2aRequestBuilder when successful

Jump to