contact

package
v1.0.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 5, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ContactRequestBuilder

ContactRequestBuilder builds and executes requests for operations under \contact

func NewContactRequestBuilder

NewContactRequestBuilder instantiates a new ContactRequestBuilder and sets the default values.

func NewContactRequestBuilderInternal

func NewContactRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ContactRequestBuilder

NewContactRequestBuilderInternal instantiates a new ContactRequestBuilder and sets the default values.

func (*ContactRequestBuilder) Post

Post submits a public contact request to Leadping support, capturing sender details and message content without requiring authentication. returns a ContactResponseable when successful returns a ProblemDetails error when the service returns a 400 status code

func (*ContactRequestBuilder) ToPostRequestInformation

ToPostRequestInformation submits a public contact request to Leadping support, capturing sender details and message content without requiring authentication. returns a *RequestInformation when successful

func (*ContactRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ContactRequestBuilder when successful

Jump to