conversations

package
v1.0.54 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 11, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConversationsItemRequestBuilder added in v1.0.49

ConversationsItemRequestBuilder builds and executes requests for operations under \conversations\{id}

func NewConversationsItemRequestBuilder added in v1.0.49

NewConversationsItemRequestBuilder instantiates a new ConversationsItemRequestBuilder and sets the default values.

func NewConversationsItemRequestBuilderInternal added in v1.0.49

func NewConversationsItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ConversationsItemRequestBuilder

NewConversationsItemRequestBuilderInternal instantiates a new ConversationsItemRequestBuilder and sets the default values.

func (*ConversationsItemRequestBuilder) MarkRead added in v1.0.49

MarkRead the markRead property returns a *ItemMarkReadRequestBuilder when successful

type ConversationsRequestBuilder

ConversationsRequestBuilder builds and executes requests for operations under \conversations

func NewConversationsRequestBuilder

NewConversationsRequestBuilder instantiates a new ConversationsRequestBuilder and sets the default values.

func NewConversationsRequestBuilderInternal

func NewConversationsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ConversationsRequestBuilder

NewConversationsRequestBuilderInternal instantiates a new ConversationsRequestBuilder and sets the default values.

func (*ConversationsRequestBuilder) ById added in v1.0.49

ById gets an item from the github.com/leadpingai/leadping-go.conversations.item collection returns a *ConversationsItemRequestBuilder when successful

func (*ConversationsRequestBuilder) Lead

Lead the lead property returns a *LeadRequestBuilder when successful

func (*ConversationsRequestBuilder) My

My the my property returns a *MyRequestBuilder when successful

type ItemMarkReadRequestBuilder added in v1.0.49

ItemMarkReadRequestBuilder builds and executes requests for operations under \conversations\{id}\mark-read

func NewItemMarkReadRequestBuilder added in v1.0.49

NewItemMarkReadRequestBuilder instantiates a new ItemMarkReadRequestBuilder and sets the default values.

func NewItemMarkReadRequestBuilderInternal added in v1.0.49

func NewItemMarkReadRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemMarkReadRequestBuilder

NewItemMarkReadRequestBuilderInternal instantiates a new ItemMarkReadRequestBuilder and sets the default values.

func (*ItemMarkReadRequestBuilder) Post added in v1.0.49

Post updates the conversation's read state for the current user's inbox and returns whether the conversation was found. returns a *bool when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ItemMarkReadRequestBuilder) ToPostRequestInformation added in v1.0.49

ToPostRequestInformation updates the conversation's read state for the current user's inbox and returns whether the conversation was found. returns a *RequestInformation when successful

func (*ItemMarkReadRequestBuilder) WithUrl added in v1.0.49

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemMarkReadRequestBuilder when successful

type LeadRequestBuilder

LeadRequestBuilder builds and executes requests for operations under \conversations\lead

func NewLeadRequestBuilder

NewLeadRequestBuilder instantiates a new LeadRequestBuilder and sets the default values.

func NewLeadRequestBuilderInternal

func NewLeadRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *LeadRequestBuilder

NewLeadRequestBuilderInternal instantiates a new LeadRequestBuilder and sets the default values.

func (*LeadRequestBuilder) ByLeadId

ByLeadId gets an item from the github.com/leadpingai/leadping-go.conversations.lead.item collection returns a *LeadWithLeadItemRequestBuilder when successful

type LeadWithLeadItemRequestBuilder

LeadWithLeadItemRequestBuilder builds and executes requests for operations under \conversations\lead\{leadId}

func NewLeadWithLeadItemRequestBuilder

NewLeadWithLeadItemRequestBuilder instantiates a new LeadWithLeadItemRequestBuilder and sets the default values.

func NewLeadWithLeadItemRequestBuilderInternal

func NewLeadWithLeadItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *LeadWithLeadItemRequestBuilder

NewLeadWithLeadItemRequestBuilderInternal instantiates a new LeadWithLeadItemRequestBuilder and sets the default values.

func (*LeadWithLeadItemRequestBuilder) Post

Post lists conversations for one lead, helping users inspect communication threads, recent follow-up, and related events. returns a PagedResultOfConversationResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code returns a ProblemDetails error when the service returns a 500 status code

func (*LeadWithLeadItemRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists conversations for one lead, helping users inspect communication threads, recent follow-up, and related events. returns a *RequestInformation when successful

func (*LeadWithLeadItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *LeadWithLeadItemRequestBuilder when successful

type MyRequestBuilder

MyRequestBuilder builds and executes requests for operations under \conversations\my

func NewMyRequestBuilder

NewMyRequestBuilder instantiates a new MyRequestBuilder and sets the default values.

func NewMyRequestBuilderInternal

func NewMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MyRequestBuilder

NewMyRequestBuilderInternal instantiates a new MyRequestBuilder and sets the default values.

func (*MyRequestBuilder) Post

Post lists the current user's lead conversations with paging and sorting for inbox views, recent follow-up, and communication history. returns a PagedResultOfConversationResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code returns a ProblemDetails error when the service returns a 500 status code

func (*MyRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists the current user's lead conversations with paging and sorting for inbox views, recent follow-up, and communication history. returns a *RequestInformation when successful

func (*MyRequestBuilder) WithUrl

func (m *MyRequestBuilder) WithUrl(rawUrl string) *MyRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *MyRequestBuilder when successful

type MyRequestBuilderPostQueryParameters

type MyRequestBuilderPostQueryParameters struct {
	// Optional filter selecting active, archived, or all lead conversations.
	ArchiveFilter *string "uriparametername:\"archiveFilter\""
}

MyRequestBuilderPostQueryParameters lists the current user's lead conversations with paging and sorting for inbox views, recent follow-up, and communication history.

Jump to