events

package
v1.0.38 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 18, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AllMyRequestBuilder

AllMyRequestBuilder builds and executes requests for operations under \events\all\my

func NewAllMyRequestBuilder

NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.

func NewAllMyRequestBuilderInternal

func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder

NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.

func (*AllMyRequestBuilder) Post

Post lists event records visible to the current user with paging, sorting, and filters across lead, SMS, call, and automation events. returns a PagedResultOfEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*AllMyRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists event records visible to the current user with paging, sorting, and filters across lead, SMS, call, and automation events. returns a *RequestInformation when successful

func (*AllMyRequestBuilder) WithUrl

func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful

type AllMyRequestBuilderPostQueryParameters

type AllMyRequestBuilderPostQueryParameters struct {
	// Optional event category used to narrow the results.
	Category *string "uriparametername:\"category\""
	// Optional exclusive end timestamp for event occurrence.
	EndAt *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"endAt\""
	// Optional inclusive start timestamp for event occurrence.
	StartAt *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"startAt\""
}

AllMyRequestBuilderPostQueryParameters lists event records visible to the current user with paging, sorting, and filters across lead, SMS, call, and automation events.

type AllRequestBuilder

AllRequestBuilder builds and executes requests for operations under \events\all

func NewAllRequestBuilder

NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.

func NewAllRequestBuilderInternal

func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder

NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.

func (*AllRequestBuilder) My

My the my property returns a *AllMyRequestBuilder when successful

type CallsAllMyRequestBuilder

CallsAllMyRequestBuilder builds and executes requests for operations under \events\calls\all\my

func NewCallsAllMyRequestBuilder

NewCallsAllMyRequestBuilder instantiates a new CallsAllMyRequestBuilder and sets the default values.

func NewCallsAllMyRequestBuilderInternal

func NewCallsAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsAllMyRequestBuilder

NewCallsAllMyRequestBuilderInternal instantiates a new CallsAllMyRequestBuilder and sets the default values.

func (*CallsAllMyRequestBuilder) Post

Post lists call events visible to the current user with paging, sorting, and filters for call history and lead follow-up review. returns a PagedResultOfCallEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*CallsAllMyRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists call events visible to the current user with paging, sorting, and filters for call history and lead follow-up review. returns a *RequestInformation when successful

func (*CallsAllMyRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *CallsAllMyRequestBuilder when successful

type CallsAllRequestBuilder

CallsAllRequestBuilder builds and executes requests for operations under \events\calls\all

func NewCallsAllRequestBuilder

NewCallsAllRequestBuilder instantiates a new CallsAllRequestBuilder and sets the default values.

func NewCallsAllRequestBuilderInternal

func NewCallsAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsAllRequestBuilder

NewCallsAllRequestBuilderInternal instantiates a new CallsAllRequestBuilder and sets the default values.

func (*CallsAllRequestBuilder) My

My the my property returns a *CallsAllMyRequestBuilder when successful

type CallsLeadRequestBuilder

CallsLeadRequestBuilder builds and executes requests for operations under \events\calls\lead

func NewCallsLeadRequestBuilder

NewCallsLeadRequestBuilder instantiates a new CallsLeadRequestBuilder and sets the default values.

func NewCallsLeadRequestBuilderInternal

func NewCallsLeadRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsLeadRequestBuilder

NewCallsLeadRequestBuilderInternal instantiates a new CallsLeadRequestBuilder and sets the default values.

func (*CallsLeadRequestBuilder) ByLeadId

ByLeadId gets an item from the github.com/leadpingai/leadping-go.events.calls.lead.item collection returns a *CallsLeadWithLeadItemRequestBuilder when successful

type CallsLeadWithLeadItemRequestBuilder

CallsLeadWithLeadItemRequestBuilder builds and executes requests for operations under \events\calls\lead\{leadId}

func NewCallsLeadWithLeadItemRequestBuilder

NewCallsLeadWithLeadItemRequestBuilder instantiates a new CallsLeadWithLeadItemRequestBuilder and sets the default values.

func NewCallsLeadWithLeadItemRequestBuilderInternal

func NewCallsLeadWithLeadItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsLeadWithLeadItemRequestBuilder

NewCallsLeadWithLeadItemRequestBuilderInternal instantiates a new CallsLeadWithLeadItemRequestBuilder and sets the default values.

func (*CallsLeadWithLeadItemRequestBuilder) Post

Post lists call events for one lead with paging, helping users review call attempts, outcomes, and follow-up history. returns a PagedResultOfCallEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*CallsLeadWithLeadItemRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists call events for one lead with paging, helping users review call attempts, outcomes, and follow-up history. returns a *RequestInformation when successful

func (*CallsLeadWithLeadItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *CallsLeadWithLeadItemRequestBuilder when successful

type CallsPhoneRequestBuilder

CallsPhoneRequestBuilder builds and executes requests for operations under \events\calls\phone

func NewCallsPhoneRequestBuilder

NewCallsPhoneRequestBuilder instantiates a new CallsPhoneRequestBuilder and sets the default values.

func NewCallsPhoneRequestBuilderInternal

func NewCallsPhoneRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsPhoneRequestBuilder

NewCallsPhoneRequestBuilderInternal instantiates a new CallsPhoneRequestBuilder and sets the default values.

func (*CallsPhoneRequestBuilder) ByPhoneNumber

ByPhoneNumber gets an item from the github.com/leadpingai/leadping-go.events.calls.phone.item collection returns a *CallsPhoneWithPhoneNumberItemRequestBuilder when successful

type CallsPhoneWithPhoneNumberItemRequestBuilder

type CallsPhoneWithPhoneNumberItemRequestBuilder struct {
	i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}

CallsPhoneWithPhoneNumberItemRequestBuilder builds and executes requests for operations under \events\calls\phone\{phoneNumber}

func NewCallsPhoneWithPhoneNumberItemRequestBuilder

NewCallsPhoneWithPhoneNumberItemRequestBuilder instantiates a new CallsPhoneWithPhoneNumberItemRequestBuilder and sets the default values.

func NewCallsPhoneWithPhoneNumberItemRequestBuilderInternal

func NewCallsPhoneWithPhoneNumberItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsPhoneWithPhoneNumberItemRequestBuilder

NewCallsPhoneWithPhoneNumberItemRequestBuilderInternal instantiates a new CallsPhoneWithPhoneNumberItemRequestBuilder and sets the default values.

func (*CallsPhoneWithPhoneNumberItemRequestBuilder) Post

Post lists call events for one phone number with paging, helping users review volume, outcomes, and communication history. returns a PagedResultOfCallEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*CallsPhoneWithPhoneNumberItemRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists call events for one phone number with paging, helping users review volume, outcomes, and communication history. returns a *RequestInformation when successful

func (*CallsPhoneWithPhoneNumberItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *CallsPhoneWithPhoneNumberItemRequestBuilder when successful

type CallsRequestBuilder

CallsRequestBuilder builds and executes requests for operations under \events\calls

func NewCallsRequestBuilder

NewCallsRequestBuilder instantiates a new CallsRequestBuilder and sets the default values.

func NewCallsRequestBuilderInternal

func NewCallsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsRequestBuilder

NewCallsRequestBuilderInternal instantiates a new CallsRequestBuilder and sets the default values.

func (*CallsRequestBuilder) All

All the all property returns a *CallsAllRequestBuilder when successful

func (*CallsRequestBuilder) ByCallEventId

func (m *CallsRequestBuilder) ByCallEventId(callEventId string) *CallsWithCallEventItemRequestBuilder

ByCallEventId gets an item from the github.com/leadpingai/leadping-go.events.calls.item collection returns a *CallsWithCallEventItemRequestBuilder when successful

func (*CallsRequestBuilder) Lead

Lead the lead property returns a *CallsLeadRequestBuilder when successful

func (*CallsRequestBuilder) Phone

Phone the phone property returns a *CallsPhoneRequestBuilder when successful

type CallsWithCallEventItemRequestBuilder

type CallsWithCallEventItemRequestBuilder struct {
	i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}

CallsWithCallEventItemRequestBuilder builds and executes requests for operations under \events\calls\{callEventId}

func NewCallsWithCallEventItemRequestBuilder

NewCallsWithCallEventItemRequestBuilder instantiates a new CallsWithCallEventItemRequestBuilder and sets the default values.

func NewCallsWithCallEventItemRequestBuilderInternal

func NewCallsWithCallEventItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CallsWithCallEventItemRequestBuilder

NewCallsWithCallEventItemRequestBuilderInternal instantiates a new CallsWithCallEventItemRequestBuilder and sets the default values.

func (*CallsWithCallEventItemRequestBuilder) Get

Get returns one call event, including call metadata, provider status, related lead, and communication context. returns a CallEventTableRowable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*CallsWithCallEventItemRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns one call event, including call metadata, provider status, related lead, and communication context. returns a *RequestInformation when successful

func (*CallsWithCallEventItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *CallsWithCallEventItemRequestBuilder when successful

type ConversationsItemNotesRequestBuilder

type ConversationsItemNotesRequestBuilder struct {
	i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}

ConversationsItemNotesRequestBuilder builds and executes requests for operations under \events\conversations\{conversationId}\notes

func NewConversationsItemNotesRequestBuilder

NewConversationsItemNotesRequestBuilder instantiates a new ConversationsItemNotesRequestBuilder and sets the default values.

func NewConversationsItemNotesRequestBuilderInternal

func NewConversationsItemNotesRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ConversationsItemNotesRequestBuilder

NewConversationsItemNotesRequestBuilderInternal instantiates a new ConversationsItemNotesRequestBuilder and sets the default values.

func (*ConversationsItemNotesRequestBuilder) Post

Post creates a note event on a conversation so users can document lead context, handoffs, and follow-up details. returns a EventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ConversationsItemNotesRequestBuilder) ToPostRequestInformation

ToPostRequestInformation creates a note event on a conversation so users can document lead context, handoffs, and follow-up details. returns a *RequestInformation when successful

func (*ConversationsItemNotesRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ConversationsItemNotesRequestBuilder when successful

type ConversationsRequestBuilder

ConversationsRequestBuilder builds and executes requests for operations under \events\conversations

func NewConversationsRequestBuilder

NewConversationsRequestBuilder instantiates a new ConversationsRequestBuilder and sets the default values.

func NewConversationsRequestBuilderInternal

func NewConversationsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ConversationsRequestBuilder

NewConversationsRequestBuilderInternal instantiates a new ConversationsRequestBuilder and sets the default values.

func (*ConversationsRequestBuilder) ByConversationId

ByConversationId gets an item from the github.com/leadpingai/leadping-go.events.conversations.item collection returns a *ConversationsWithConversationItemRequestBuilder when successful

type ConversationsWithConversationItemRequestBuilder

type ConversationsWithConversationItemRequestBuilder struct {
	i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}

ConversationsWithConversationItemRequestBuilder builds and executes requests for operations under \events\conversations\{conversationId}

func NewConversationsWithConversationItemRequestBuilder

NewConversationsWithConversationItemRequestBuilder instantiates a new ConversationsWithConversationItemRequestBuilder and sets the default values.

func NewConversationsWithConversationItemRequestBuilderInternal

func NewConversationsWithConversationItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ConversationsWithConversationItemRequestBuilder

NewConversationsWithConversationItemRequestBuilderInternal instantiates a new ConversationsWithConversationItemRequestBuilder and sets the default values.

func (*ConversationsWithConversationItemRequestBuilder) Notes

Notes the notes property returns a *ConversationsItemNotesRequestBuilder when successful

func (*ConversationsWithConversationItemRequestBuilder) Post

Post lists event records for one conversation with paging, including notes, messages, calls, and follow-up history. returns a PagedResultOfEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ConversationsWithConversationItemRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists event records for one conversation with paging, including notes, messages, calls, and follow-up history. returns a *RequestInformation when successful

func (*ConversationsWithConversationItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ConversationsWithConversationItemRequestBuilder when successful

type DetailRequestBuilder added in v1.0.38

DetailRequestBuilder builds and executes requests for operations under \events\detail

func NewDetailRequestBuilder added in v1.0.38

NewDetailRequestBuilder instantiates a new DetailRequestBuilder and sets the default values.

func NewDetailRequestBuilderInternal added in v1.0.38

func NewDetailRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *DetailRequestBuilder

NewDetailRequestBuilderInternal instantiates a new DetailRequestBuilder and sets the default values.

func (*DetailRequestBuilder) ByEventId added in v1.0.38

ByEventId gets an item from the github.com/leadpingai/leadping-go.events.detail.item collection returns a *DetailWithEventItemRequestBuilder when successful

type DetailWithEventItemRequestBuilder added in v1.0.38

DetailWithEventItemRequestBuilder builds and executes requests for operations under \events\detail\{eventId}

func NewDetailWithEventItemRequestBuilder added in v1.0.38

NewDetailWithEventItemRequestBuilder instantiates a new DetailWithEventItemRequestBuilder and sets the default values.

func NewDetailWithEventItemRequestBuilderInternal added in v1.0.38

func NewDetailWithEventItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *DetailWithEventItemRequestBuilder

NewDetailWithEventItemRequestBuilderInternal instantiates a new DetailWithEventItemRequestBuilder and sets the default values.

func (*DetailWithEventItemRequestBuilder) Get added in v1.0.38

Get returns detailed event data by ID, including the full JSON payload for debugging, audit review, and workflow inspection. returns a EventDetailResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*DetailWithEventItemRequestBuilder) ToGetRequestInformation added in v1.0.38

ToGetRequestInformation returns detailed event data by ID, including the full JSON payload for debugging, audit review, and workflow inspection. returns a *RequestInformation when successful

func (*DetailWithEventItemRequestBuilder) WithUrl added in v1.0.38

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *DetailWithEventItemRequestBuilder when successful

type EventsRequestBuilder

EventsRequestBuilder builds and executes requests for operations under \events

func NewEventsRequestBuilder

NewEventsRequestBuilder instantiates a new EventsRequestBuilder and sets the default values.

func NewEventsRequestBuilderInternal

func NewEventsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *EventsRequestBuilder

NewEventsRequestBuilderInternal instantiates a new EventsRequestBuilder and sets the default values.

func (*EventsRequestBuilder) All

All the all property returns a *AllRequestBuilder when successful

func (*EventsRequestBuilder) ByEventId

ByEventId gets an item from the github.com/leadpingai/leadping-go.events.item collection returns a *WithEventItemRequestBuilder when successful

func (*EventsRequestBuilder) Calls

Calls the calls property returns a *CallsRequestBuilder when successful

func (*EventsRequestBuilder) Conversations

Conversations the conversations property returns a *ConversationsRequestBuilder when successful

func (*EventsRequestBuilder) Detail added in v1.0.38

Detail the detail property returns a *DetailRequestBuilder when successful

func (*EventsRequestBuilder) Leads

Leads the leads property returns a *LeadsRequestBuilder when successful

func (*EventsRequestBuilder) Organizations added in v1.0.29

Organizations the organizations property returns a *OrganizationsRequestBuilder when successful

func (*EventsRequestBuilder) Sms

Sms the sms property returns a *SmsRequestBuilder when successful

type LeadsRequestBuilder

LeadsRequestBuilder builds and executes requests for operations under \events\leads

func NewLeadsRequestBuilder

NewLeadsRequestBuilder instantiates a new LeadsRequestBuilder and sets the default values.

func NewLeadsRequestBuilderInternal

func NewLeadsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *LeadsRequestBuilder

NewLeadsRequestBuilderInternal instantiates a new LeadsRequestBuilder and sets the default values.

func (*LeadsRequestBuilder) ByLeadId

ByLeadId gets an item from the github.com/leadpingai/leadping-go.events.leads.item collection returns a *LeadsWithLeadItemRequestBuilder when successful

type LeadsWithLeadItemRequestBuilder

LeadsWithLeadItemRequestBuilder builds and executes requests for operations under \events\leads\{leadId}

func NewLeadsWithLeadItemRequestBuilder

NewLeadsWithLeadItemRequestBuilder instantiates a new LeadsWithLeadItemRequestBuilder and sets the default values.

func NewLeadsWithLeadItemRequestBuilderInternal

func NewLeadsWithLeadItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *LeadsWithLeadItemRequestBuilder

NewLeadsWithLeadItemRequestBuilderInternal instantiates a new LeadsWithLeadItemRequestBuilder and sets the default values.

func (*LeadsWithLeadItemRequestBuilder) Post

Post lists event records for one lead with paging, covering communication, routing, automation, and event changes. returns a PagedResultOfEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*LeadsWithLeadItemRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists event records for one lead with paging, covering communication, routing, automation, and event changes. returns a *RequestInformation when successful

func (*LeadsWithLeadItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *LeadsWithLeadItemRequestBuilder when successful

type OrganizationsRequestBuilder added in v1.0.29

OrganizationsRequestBuilder builds and executes requests for operations under \events\organizations

func NewOrganizationsRequestBuilder added in v1.0.29

NewOrganizationsRequestBuilder instantiates a new OrganizationsRequestBuilder and sets the default values.

func NewOrganizationsRequestBuilderInternal added in v1.0.29

func NewOrganizationsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OrganizationsRequestBuilder

NewOrganizationsRequestBuilderInternal instantiates a new OrganizationsRequestBuilder and sets the default values.

func (*OrganizationsRequestBuilder) ByOrganizationId added in v1.0.29

ByOrganizationId gets an item from the github.com/leadpingai/leadping-go.events.organizations.item collection returns a *OrganizationsWithOrganizationItemRequestBuilder when successful

type OrganizationsWithOrganizationItemRequestBuilder added in v1.0.29

type OrganizationsWithOrganizationItemRequestBuilder struct {
	i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}

OrganizationsWithOrganizationItemRequestBuilder builds and executes requests for operations under \events\organizations\{organizationId}

func NewOrganizationsWithOrganizationItemRequestBuilder added in v1.0.29

NewOrganizationsWithOrganizationItemRequestBuilder instantiates a new OrganizationsWithOrganizationItemRequestBuilder and sets the default values.

func NewOrganizationsWithOrganizationItemRequestBuilderInternal added in v1.0.29

func NewOrganizationsWithOrganizationItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OrganizationsWithOrganizationItemRequestBuilder

NewOrganizationsWithOrganizationItemRequestBuilderInternal instantiates a new OrganizationsWithOrganizationItemRequestBuilder and sets the default values.

func (*OrganizationsWithOrganizationItemRequestBuilder) Post added in v1.0.29

Post lists event records for an organization with paging and filters so admins can review lead communication and automation events. returns a PagedResultOfEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*OrganizationsWithOrganizationItemRequestBuilder) ToPostRequestInformation added in v1.0.29

ToPostRequestInformation lists event records for an organization with paging and filters so admins can review lead communication and automation events. returns a *RequestInformation when successful

func (*OrganizationsWithOrganizationItemRequestBuilder) WithUrl added in v1.0.29

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *OrganizationsWithOrganizationItemRequestBuilder when successful

type OrganizationsWithOrganizationItemRequestBuilderPostQueryParameters added in v1.0.29

type OrganizationsWithOrganizationItemRequestBuilderPostQueryParameters struct {
	// Optional exclusive end timestamp for event occurrence.
	EndAt *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"endAt\""
	// Optional inclusive start timestamp for event occurrence.
	StartAt *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"startAt\""
}

OrganizationsWithOrganizationItemRequestBuilderPostQueryParameters lists event records for an organization with paging and filters so admins can review lead communication and automation events.

type SmsAllMyRequestBuilder

SmsAllMyRequestBuilder builds and executes requests for operations under \events\sms\all\my

func NewSmsAllMyRequestBuilder

NewSmsAllMyRequestBuilder instantiates a new SmsAllMyRequestBuilder and sets the default values.

func NewSmsAllMyRequestBuilderInternal

func NewSmsAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsAllMyRequestBuilder

NewSmsAllMyRequestBuilderInternal instantiates a new SmsAllMyRequestBuilder and sets the default values.

func (*SmsAllMyRequestBuilder) Post

Post lists SMS events visible to the current user with paging, sorting, and filters for message history and follow-up review. returns a PagedResultOfSmsEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*SmsAllMyRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists SMS events visible to the current user with paging, sorting, and filters for message history and follow-up review. returns a *RequestInformation when successful

func (*SmsAllMyRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SmsAllMyRequestBuilder when successful

type SmsAllRequestBuilder

SmsAllRequestBuilder builds and executes requests for operations under \events\sms\all

func NewSmsAllRequestBuilder

NewSmsAllRequestBuilder instantiates a new SmsAllRequestBuilder and sets the default values.

func NewSmsAllRequestBuilderInternal

func NewSmsAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsAllRequestBuilder

NewSmsAllRequestBuilderInternal instantiates a new SmsAllRequestBuilder and sets the default values.

func (*SmsAllRequestBuilder) My

My the my property returns a *SmsAllMyRequestBuilder when successful

type SmsLeadRequestBuilder

SmsLeadRequestBuilder builds and executes requests for operations under \events\sms\lead

func NewSmsLeadRequestBuilder

NewSmsLeadRequestBuilder instantiates a new SmsLeadRequestBuilder and sets the default values.

func NewSmsLeadRequestBuilderInternal

func NewSmsLeadRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsLeadRequestBuilder

NewSmsLeadRequestBuilderInternal instantiates a new SmsLeadRequestBuilder and sets the default values.

func (*SmsLeadRequestBuilder) ByLeadId

ByLeadId gets an item from the github.com/leadpingai/leadping-go.events.sms.lead.item collection returns a *SmsLeadWithLeadItemRequestBuilder when successful

type SmsLeadWithLeadItemRequestBuilder

SmsLeadWithLeadItemRequestBuilder builds and executes requests for operations under \events\sms\lead\{leadId}

func NewSmsLeadWithLeadItemRequestBuilder

NewSmsLeadWithLeadItemRequestBuilder instantiates a new SmsLeadWithLeadItemRequestBuilder and sets the default values.

func NewSmsLeadWithLeadItemRequestBuilderInternal

func NewSmsLeadWithLeadItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsLeadWithLeadItemRequestBuilder

NewSmsLeadWithLeadItemRequestBuilderInternal instantiates a new SmsLeadWithLeadItemRequestBuilder and sets the default values.

func (*SmsLeadWithLeadItemRequestBuilder) Post

Post lists SMS events for one lead with paging, helping users review sent messages, scheduled messages, and delivery outcomes. returns a PagedResultOfSmsEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*SmsLeadWithLeadItemRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists SMS events for one lead with paging, helping users review sent messages, scheduled messages, and delivery outcomes. returns a *RequestInformation when successful

func (*SmsLeadWithLeadItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SmsLeadWithLeadItemRequestBuilder when successful

type SmsPhoneRequestBuilder

SmsPhoneRequestBuilder builds and executes requests for operations under \events\sms\phone

func NewSmsPhoneRequestBuilder

NewSmsPhoneRequestBuilder instantiates a new SmsPhoneRequestBuilder and sets the default values.

func NewSmsPhoneRequestBuilderInternal

func NewSmsPhoneRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsPhoneRequestBuilder

NewSmsPhoneRequestBuilderInternal instantiates a new SmsPhoneRequestBuilder and sets the default values.

func (*SmsPhoneRequestBuilder) ByPhoneNumber

ByPhoneNumber gets an item from the github.com/leadpingai/leadping-go.events.sms.phone.item collection returns a *SmsPhoneWithPhoneNumberItemRequestBuilder when successful

type SmsPhoneWithPhoneNumberItemRequestBuilder

type SmsPhoneWithPhoneNumberItemRequestBuilder struct {
	i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}

SmsPhoneWithPhoneNumberItemRequestBuilder builds and executes requests for operations under \events\sms\phone\{phoneNumber}

func NewSmsPhoneWithPhoneNumberItemRequestBuilder

NewSmsPhoneWithPhoneNumberItemRequestBuilder instantiates a new SmsPhoneWithPhoneNumberItemRequestBuilder and sets the default values.

func NewSmsPhoneWithPhoneNumberItemRequestBuilderInternal

func NewSmsPhoneWithPhoneNumberItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsPhoneWithPhoneNumberItemRequestBuilder

NewSmsPhoneWithPhoneNumberItemRequestBuilderInternal instantiates a new SmsPhoneWithPhoneNumberItemRequestBuilder and sets the default values.

func (*SmsPhoneWithPhoneNumberItemRequestBuilder) Post

Post lists SMS events for one phone number with paging, helping users review volume, delivery outcomes, and communication history. returns a PagedResultOfSmsEventTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*SmsPhoneWithPhoneNumberItemRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists SMS events for one phone number with paging, helping users review volume, delivery outcomes, and communication history. returns a *RequestInformation when successful

func (*SmsPhoneWithPhoneNumberItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SmsPhoneWithPhoneNumberItemRequestBuilder when successful

type SmsRequestBuilder

SmsRequestBuilder builds and executes requests for operations under \events\sms

func NewSmsRequestBuilder

NewSmsRequestBuilder instantiates a new SmsRequestBuilder and sets the default values.

func NewSmsRequestBuilderInternal

func NewSmsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsRequestBuilder

NewSmsRequestBuilderInternal instantiates a new SmsRequestBuilder and sets the default values.

func (*SmsRequestBuilder) All

All the all property returns a *SmsAllRequestBuilder when successful

func (*SmsRequestBuilder) BySmsEventId

func (m *SmsRequestBuilder) BySmsEventId(smsEventId string) *SmsWithSmsEventItemRequestBuilder

BySmsEventId gets an item from the github.com/leadpingai/leadping-go.events.sms.item collection returns a *SmsWithSmsEventItemRequestBuilder when successful

func (*SmsRequestBuilder) Lead

Lead the lead property returns a *SmsLeadRequestBuilder when successful

func (*SmsRequestBuilder) Phone

Phone the phone property returns a *SmsPhoneRequestBuilder when successful

type SmsWithSmsEventItemRequestBuilder

SmsWithSmsEventItemRequestBuilder builds and executes requests for operations under \events\sms\{smsEventId}

func NewSmsWithSmsEventItemRequestBuilder

NewSmsWithSmsEventItemRequestBuilder instantiates a new SmsWithSmsEventItemRequestBuilder and sets the default values.

func NewSmsWithSmsEventItemRequestBuilderInternal

func NewSmsWithSmsEventItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsWithSmsEventItemRequestBuilder

NewSmsWithSmsEventItemRequestBuilderInternal instantiates a new SmsWithSmsEventItemRequestBuilder and sets the default values.

func (*SmsWithSmsEventItemRequestBuilder) Get

Get returns one SMS event, including message metadata, provider status, related lead, and delivery context. returns a SmsEventTableRowable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*SmsWithSmsEventItemRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns one SMS event, including message metadata, provider status, related lead, and delivery context. returns a *RequestInformation when successful

func (*SmsWithSmsEventItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SmsWithSmsEventItemRequestBuilder when successful

type WithEventItemRequestBuilder

WithEventItemRequestBuilder builds and executes requests for operations under \events\{eventId}

func NewWithEventItemRequestBuilder

NewWithEventItemRequestBuilder instantiates a new WithEventItemRequestBuilder and sets the default values.

func NewWithEventItemRequestBuilderInternal

func NewWithEventItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *WithEventItemRequestBuilder

NewWithEventItemRequestBuilderInternal instantiates a new WithEventItemRequestBuilder and sets the default values.

func (*WithEventItemRequestBuilder) Get

Get returns one event record by ID, including event type, timestamps, related entities, and summary payload data. returns a EventTableRowable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*WithEventItemRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns one event record by ID, including event type, timestamps, related entities, and summary payload data. returns a *RequestInformation when successful

func (*WithEventItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *WithEventItemRequestBuilder when successful

Jump to