feedback

package
v1.0.24 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 24, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FeedbackRequestBuilder

FeedbackRequestBuilder builds and executes requests for operations under \feedback

func NewFeedbackRequestBuilder

NewFeedbackRequestBuilder instantiates a new FeedbackRequestBuilder and sets the default values.

func NewFeedbackRequestBuilderInternal

func NewFeedbackRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *FeedbackRequestBuilder

NewFeedbackRequestBuilderInternal instantiates a new FeedbackRequestBuilder and sets the default values.

func (*FeedbackRequestBuilder) Post

Post creates product feedback for the current business, capturing category, message, and context for operator review. returns a FeedbackResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code

func (*FeedbackRequestBuilder) ToPostRequestInformation

ToPostRequestInformation creates product feedback for the current business, capturing category, message, and context for operator review. returns a *RequestInformation when successful

func (*FeedbackRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *FeedbackRequestBuilder when successful

Jump to