outbound

package
v1.0.31 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type OutboundRequestBuilder

OutboundRequestBuilder builds and executes requests for operations under \outbound

func NewOutboundRequestBuilder

NewOutboundRequestBuilder instantiates a new OutboundRequestBuilder and sets the default values.

func NewOutboundRequestBuilderInternal

func NewOutboundRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OutboundRequestBuilder

NewOutboundRequestBuilderInternal instantiates a new OutboundRequestBuilder and sets the default values.

func (*OutboundRequestBuilder) Overview

Overview the overview property returns a *OverviewRequestBuilder when successful

type OverviewRequestBuilder

OverviewRequestBuilder builds and executes requests for operations under \outbound\overview

func NewOverviewRequestBuilder

NewOverviewRequestBuilder instantiates a new OverviewRequestBuilder and sets the default values.

func NewOverviewRequestBuilderInternal

func NewOverviewRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OverviewRequestBuilder

NewOverviewRequestBuilderInternal instantiates a new OverviewRequestBuilder and sets the default values.

func (*OverviewRequestBuilder) Get

Get returns current-organization outbound capacity, scheduled work, and pacing decisions used to control lead communication delivery. returns a OutboundCapacityOverviewable when successful returns a ProblemDetails error when the service returns a 401 status code

func (*OverviewRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns current-organization outbound capacity, scheduled work, and pacing decisions used to control lead communication delivery. returns a *RequestInformation when successful

func (*OverviewRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *OverviewRequestBuilder when successful

Jump to