paymentmethods

package
v1.0.33 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type InvoicesItemPdfAccessRequestBuilder added in v1.0.22

InvoicesItemPdfAccessRequestBuilder builds and executes requests for operations under \payment-methods\invoices\{invoiceId}\pdf-access

func NewInvoicesItemPdfAccessRequestBuilder added in v1.0.22

NewInvoicesItemPdfAccessRequestBuilder instantiates a new InvoicesItemPdfAccessRequestBuilder and sets the default values.

func NewInvoicesItemPdfAccessRequestBuilderInternal added in v1.0.22

func NewInvoicesItemPdfAccessRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *InvoicesItemPdfAccessRequestBuilder

NewInvoicesItemPdfAccessRequestBuilderInternal instantiates a new InvoicesItemPdfAccessRequestBuilder and sets the default values.

func (*InvoicesItemPdfAccessRequestBuilder) Get added in v1.0.22

Get creates a short-lived, secure URL that lets the current organization view or download a private Stripe invoice PDF without exposing a permanent file link. returns a InvoicePdfAccessResponseable when successful returns a ProblemDetails error when the service returns a 404 status code

func (*InvoicesItemPdfAccessRequestBuilder) ToGetRequestInformation added in v1.0.22

ToGetRequestInformation creates a short-lived, secure URL that lets the current organization view or download a private Stripe invoice PDF without exposing a permanent file link. returns a *RequestInformation when successful

func (*InvoicesItemPdfAccessRequestBuilder) WithUrl added in v1.0.22

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *InvoicesItemPdfAccessRequestBuilder when successful

type InvoicesItemPdfAccessRequestBuilderGetQueryParameters added in v1.0.22

type InvoicesItemPdfAccessRequestBuilderGetQueryParameters struct {
	// Whether the secure URL should download the PDF instead of displaying it inline.
	Download *bool "uriparametername:\"download\""
}

InvoicesItemPdfAccessRequestBuilderGetQueryParameters creates a short-lived, secure URL that lets the current organization view or download a private Stripe invoice PDF without exposing a permanent file link.

type InvoicesRequestBuilder added in v1.0.21

InvoicesRequestBuilder builds and executes requests for operations under \payment-methods\invoices

func NewInvoicesRequestBuilder added in v1.0.21

NewInvoicesRequestBuilder instantiates a new InvoicesRequestBuilder and sets the default values.

func NewInvoicesRequestBuilderInternal added in v1.0.21

func NewInvoicesRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *InvoicesRequestBuilder

NewInvoicesRequestBuilderInternal instantiates a new InvoicesRequestBuilder and sets the default values.

func (*InvoicesRequestBuilder) ByInvoiceId added in v1.0.22

ByInvoiceId gets an item from the github.com/leadpingai/leadping-go.paymentMethods.invoices.item collection returns a *InvoicesWithInvoiceItemRequestBuilder when successful

func (*InvoicesRequestBuilder) Get added in v1.0.21

Get returns the current organization's Stripe invoices with their amounts, payment status, billing period, and hosted invoice details. returns a []StripeInvoiceResponseable when successful

func (*InvoicesRequestBuilder) ToGetRequestInformation added in v1.0.21

ToGetRequestInformation returns the current organization's Stripe invoices with their amounts, payment status, billing period, and hosted invoice details. returns a *RequestInformation when successful

func (*InvoicesRequestBuilder) WithUrl added in v1.0.21

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *InvoicesRequestBuilder when successful

type InvoicesWithInvoiceItemRequestBuilder added in v1.0.22

type InvoicesWithInvoiceItemRequestBuilder struct {
	i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}

InvoicesWithInvoiceItemRequestBuilder builds and executes requests for operations under \payment-methods\invoices\{invoiceId}

func NewInvoicesWithInvoiceItemRequestBuilder added in v1.0.22

NewInvoicesWithInvoiceItemRequestBuilder instantiates a new InvoicesWithInvoiceItemRequestBuilder and sets the default values.

func NewInvoicesWithInvoiceItemRequestBuilderInternal added in v1.0.22

func NewInvoicesWithInvoiceItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *InvoicesWithInvoiceItemRequestBuilder

NewInvoicesWithInvoiceItemRequestBuilderInternal instantiates a new InvoicesWithInvoiceItemRequestBuilder and sets the default values.

func (*InvoicesWithInvoiceItemRequestBuilder) PdfAccess added in v1.0.22

PdfAccess the pdfAccess property returns a *InvoicesItemPdfAccessRequestBuilder when successful

type ItemDefaultRequestBuilder added in v1.0.15

ItemDefaultRequestBuilder builds and executes requests for operations under \payment-methods\{id}\default

func NewItemDefaultRequestBuilder added in v1.0.15

NewItemDefaultRequestBuilder instantiates a new ItemDefaultRequestBuilder and sets the default values.

func NewItemDefaultRequestBuilderInternal added in v1.0.15

func NewItemDefaultRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemDefaultRequestBuilder

NewItemDefaultRequestBuilderInternal instantiates a new ItemDefaultRequestBuilder and sets the default values.

func (*ItemDefaultRequestBuilder) Post added in v1.0.15

Post sets a payment method as the default for the current organization's future invoices and billing activity. returns a StripePaymentMethodResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code

func (*ItemDefaultRequestBuilder) ToPostRequestInformation added in v1.0.15

ToPostRequestInformation sets a payment method as the default for the current organization's future invoices and billing activity. returns a *RequestInformation when successful

func (*ItemDefaultRequestBuilder) WithUrl added in v1.0.15

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemDefaultRequestBuilder when successful

type PaymentMethodsItemRequestBuilder

PaymentMethodsItemRequestBuilder builds and executes requests for operations under \payment-methods\{id}

func NewPaymentMethodsItemRequestBuilder

NewPaymentMethodsItemRequestBuilder instantiates a new PaymentMethodsItemRequestBuilder and sets the default values.

func NewPaymentMethodsItemRequestBuilderInternal

func NewPaymentMethodsItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *PaymentMethodsItemRequestBuilder

NewPaymentMethodsItemRequestBuilderInternal instantiates a new PaymentMethodsItemRequestBuilder and sets the default values.

func (*PaymentMethodsItemRequestBuilder) DefaultEscaped added in v1.0.15

DefaultEscaped the default property returns a *ItemDefaultRequestBuilder when successful

func (*PaymentMethodsItemRequestBuilder) Delete

Delete deletes a payment method so it is no longer available for wallet funding, invoices, or billing account management. returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code

func (*PaymentMethodsItemRequestBuilder) Get

Get returns one payment method for the current user or organization, including card metadata used for billing management. returns a StripePaymentMethodResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code

func (*PaymentMethodsItemRequestBuilder) ToDeleteRequestInformation

ToDeleteRequestInformation deletes a payment method so it is no longer available for wallet funding, invoices, or billing account management. returns a *RequestInformation when successful

func (*PaymentMethodsItemRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns one payment method for the current user or organization, including card metadata used for billing management. returns a *RequestInformation when successful

func (*PaymentMethodsItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *PaymentMethodsItemRequestBuilder when successful

type PaymentMethodsRequestBuilder

PaymentMethodsRequestBuilder builds and executes requests for operations under \payment-methods

func NewPaymentMethodsRequestBuilder

NewPaymentMethodsRequestBuilder instantiates a new PaymentMethodsRequestBuilder and sets the default values.

func NewPaymentMethodsRequestBuilderInternal

func NewPaymentMethodsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *PaymentMethodsRequestBuilder

NewPaymentMethodsRequestBuilderInternal instantiates a new PaymentMethodsRequestBuilder and sets the default values.

func (*PaymentMethodsRequestBuilder) ById

ById gets an item from the github.com/leadpingai/leadping-go.paymentMethods.item collection returns a *PaymentMethodsItemRequestBuilder when successful

func (*PaymentMethodsRequestBuilder) Get added in v1.0.15

Get lists the payment methods available to the current organization for billing, invoice payments, and wallet funding. returns a []StripePaymentMethodResponseable when successful returns a ProblemDetails error when the service returns a 401 status code

func (*PaymentMethodsRequestBuilder) Invoices added in v1.0.21

Invoices the invoices property returns a *InvoicesRequestBuilder when successful

func (*PaymentMethodsRequestBuilder) ToGetRequestInformation added in v1.0.15

ToGetRequestInformation lists the payment methods available to the current organization for billing, invoice payments, and wallet funding. returns a *RequestInformation when successful

func (*PaymentMethodsRequestBuilder) WithUrl added in v1.0.15

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *PaymentMethodsRequestBuilder when successful

Jump to