phonecall

package
v1.0.59 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 17, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type InitiateRequestBuilder

InitiateRequestBuilder builds and executes requests for operations under \phone-call\initiate

func NewInitiateRequestBuilder

NewInitiateRequestBuilder instantiates a new InitiateRequestBuilder and sets the default values.

func NewInitiateRequestBuilderInternal

func NewInitiateRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *InitiateRequestBuilder

NewInitiateRequestBuilderInternal instantiates a new InitiateRequestBuilder and sets the default values.

func (*InitiateRequestBuilder) Post

Post the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a PhoneCallResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*InitiateRequestBuilder) ToPostRequestInformation

ToPostRequestInformation the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a *RequestInformation when successful

func (*InitiateRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *InitiateRequestBuilder when successful

type ItemHangupRequestBuilder

ItemHangupRequestBuilder builds and executes requests for operations under \phone-call\{callId}\hangup

func NewItemHangupRequestBuilder

NewItemHangupRequestBuilder instantiates a new ItemHangupRequestBuilder and sets the default values.

func NewItemHangupRequestBuilderInternal

func NewItemHangupRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemHangupRequestBuilder

NewItemHangupRequestBuilderInternal instantiates a new ItemHangupRequestBuilder and sets the default values.

func (*ItemHangupRequestBuilder) Post

Post the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a PhoneCallResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ItemHangupRequestBuilder) ToPostRequestInformation

ToPostRequestInformation the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a *RequestInformation when successful

func (*ItemHangupRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemHangupRequestBuilder when successful

type ItemStatusRequestBuilder

ItemStatusRequestBuilder builds and executes requests for operations under \phone-call\{callId}\status

func NewItemStatusRequestBuilder

NewItemStatusRequestBuilder instantiates a new ItemStatusRequestBuilder and sets the default values.

func NewItemStatusRequestBuilderInternal

func NewItemStatusRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemStatusRequestBuilder

NewItemStatusRequestBuilderInternal instantiates a new ItemStatusRequestBuilder and sets the default values.

func (*ItemStatusRequestBuilder) Get

Get the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a PhoneCallResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ItemStatusRequestBuilder) ToGetRequestInformation

ToGetRequestInformation the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a *RequestInformation when successful

func (*ItemStatusRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemStatusRequestBuilder when successful

type ItemTransferRequestBuilder

ItemTransferRequestBuilder builds and executes requests for operations under \phone-call\{callId}\transfer

func NewItemTransferRequestBuilder

NewItemTransferRequestBuilder instantiates a new ItemTransferRequestBuilder and sets the default values.

func NewItemTransferRequestBuilderInternal

func NewItemTransferRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemTransferRequestBuilder

NewItemTransferRequestBuilderInternal instantiates a new ItemTransferRequestBuilder and sets the default values.

func (*ItemTransferRequestBuilder) Post

Post the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a PhoneCallResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ItemTransferRequestBuilder) ToPostRequestInformation

ToPostRequestInformation the call operation validates ownership and current provider state before returning the updated Leadping call representation. returns a *RequestInformation when successful

func (*ItemTransferRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemTransferRequestBuilder when successful

type ItemTransferRequestBuilderPostQueryParameters

type ItemTransferRequestBuilderPostQueryParameters struct {
	// The phone number to transfer the call to.
	NewPhoneNumber *string "uriparametername:\"newPhoneNumber\""
}

ItemTransferRequestBuilderPostQueryParameters the call operation validates ownership and current provider state before returning the updated Leadping call representation.

type PhoneCallRequestBuilder

PhoneCallRequestBuilder builds and executes requests for operations under \phone-call

func NewPhoneCallRequestBuilder

NewPhoneCallRequestBuilder instantiates a new PhoneCallRequestBuilder and sets the default values.

func NewPhoneCallRequestBuilderInternal

func NewPhoneCallRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *PhoneCallRequestBuilder

NewPhoneCallRequestBuilderInternal instantiates a new PhoneCallRequestBuilder and sets the default values.

func (*PhoneCallRequestBuilder) ByCallId

ByCallId gets an item from the github.com/leadpingai/leadping-go.phoneCall.item collection returns a *WithCallItemRequestBuilder when successful

func (*PhoneCallRequestBuilder) Initiate

Initiate the initiate property returns a *InitiateRequestBuilder when successful

type WithCallItemRequestBuilder

WithCallItemRequestBuilder builds and executes requests for operations under \phone-call\{callId}

func NewWithCallItemRequestBuilder

NewWithCallItemRequestBuilder instantiates a new WithCallItemRequestBuilder and sets the default values.

func NewWithCallItemRequestBuilderInternal

func NewWithCallItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *WithCallItemRequestBuilder

NewWithCallItemRequestBuilderInternal instantiates a new WithCallItemRequestBuilder and sets the default values.

func (*WithCallItemRequestBuilder) Hangup

Hangup the hangup property returns a *ItemHangupRequestBuilder when successful

func (*WithCallItemRequestBuilder) Status

Status the status property returns a *ItemStatusRequestBuilder when successful

func (*WithCallItemRequestBuilder) Transfer

Transfer the transfer property returns a *ItemTransferRequestBuilder when successful

Jump to