sms

package
v1.0.22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ItemCancelRequestBuilder

ItemCancelRequestBuilder builds and executes requests for operations under \sms\{smsEventId}\cancel

func NewItemCancelRequestBuilder

NewItemCancelRequestBuilder instantiates a new ItemCancelRequestBuilder and sets the default values.

func NewItemCancelRequestBuilderInternal

func NewItemCancelRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemCancelRequestBuilder

NewItemCancelRequestBuilderInternal instantiates a new ItemCancelRequestBuilder and sets the default values.

func (*ItemCancelRequestBuilder) Post

Post cancels a scheduled SMS event before delivery, preserving the event record while preventing the queued message from being sent. returns a SmsResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code

func (*ItemCancelRequestBuilder) ToPostRequestInformation

ToPostRequestInformation cancels a scheduled SMS event before delivery, preserving the event record while preventing the queued message from being sent. returns a *RequestInformation when successful

func (*ItemCancelRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemCancelRequestBuilder when successful

type SendRequestBuilder

SendRequestBuilder builds and executes requests for operations under \sms\send

func NewSendRequestBuilder

NewSendRequestBuilder instantiates a new SendRequestBuilder and sets the default values.

func NewSendRequestBuilderInternal

func NewSendRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SendRequestBuilder

NewSendRequestBuilderInternal instantiates a new SendRequestBuilder and sets the default values.

func (*SendRequestBuilder) Post

Post sends an SMS message to a lead or phone number, applying current-business sender selection, scheduling, and delivery rules. returns a SmsResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 500 status code

func (*SendRequestBuilder) ToPostRequestInformation

ToPostRequestInformation sends an SMS message to a lead or phone number, applying current-business sender selection, scheduling, and delivery rules. returns a *RequestInformation when successful

func (*SendRequestBuilder) WithUrl

func (m *SendRequestBuilder) WithUrl(rawUrl string) *SendRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SendRequestBuilder when successful

type SmsRequestBuilder

SmsRequestBuilder builds and executes requests for operations under \sms

func NewSmsRequestBuilder

NewSmsRequestBuilder instantiates a new SmsRequestBuilder and sets the default values.

func NewSmsRequestBuilderInternal

func NewSmsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsRequestBuilder

NewSmsRequestBuilderInternal instantiates a new SmsRequestBuilder and sets the default values.

func (*SmsRequestBuilder) BySmsEventId

func (m *SmsRequestBuilder) BySmsEventId(smsEventId string) *WithSmsEventItemRequestBuilder

BySmsEventId gets an item from the github.com/leadpingai/leadping-go.sms.item collection returns a *WithSmsEventItemRequestBuilder when successful

func (*SmsRequestBuilder) Send

Send the send property returns a *SendRequestBuilder when successful

type WithSmsEventItemRequestBuilder

WithSmsEventItemRequestBuilder builds and executes requests for operations under \sms\{smsEventId}

func NewWithSmsEventItemRequestBuilder

NewWithSmsEventItemRequestBuilder instantiates a new WithSmsEventItemRequestBuilder and sets the default values.

func NewWithSmsEventItemRequestBuilderInternal

func NewWithSmsEventItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *WithSmsEventItemRequestBuilder

NewWithSmsEventItemRequestBuilderInternal instantiates a new WithSmsEventItemRequestBuilder and sets the default values.

func (*WithSmsEventItemRequestBuilder) Cancel

Cancel the cancel property returns a *ItemCancelRequestBuilder when successful

Jump to