suppressions

package
v1.0.34 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AllMyRequestBuilder added in v1.0.28

AllMyRequestBuilder builds and executes requests for operations under \suppressions\all\my

func NewAllMyRequestBuilder added in v1.0.28

NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.

func NewAllMyRequestBuilderInternal added in v1.0.28

func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder

NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.

func (*AllMyRequestBuilder) Post added in v1.0.28

Post returns a filtered, paginated list of recipients the current organization has blocked from phone, SMS, or email outreach. returns a PagedResultOfSuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 401 status code

func (*AllMyRequestBuilder) ToPostRequestInformation added in v1.0.28

ToPostRequestInformation returns a filtered, paginated list of recipients the current organization has blocked from phone, SMS, or email outreach. returns a *RequestInformation when successful

func (*AllMyRequestBuilder) WithUrl added in v1.0.28

func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful

type AllRequestBuilder added in v1.0.28

AllRequestBuilder builds and executes requests for operations under \suppressions\all

func NewAllRequestBuilder added in v1.0.28

NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.

func NewAllRequestBuilderInternal added in v1.0.28

func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder

NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.

func (*AllRequestBuilder) My added in v1.0.28

My the my property returns a *AllMyRequestBuilder when successful

type CheckRequestBuilder

CheckRequestBuilder builds and executes requests for operations under \suppressions\check

func NewCheckRequestBuilder

NewCheckRequestBuilder instantiates a new CheckRequestBuilder and sets the default values.

func NewCheckRequestBuilderInternal

func NewCheckRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CheckRequestBuilder

NewCheckRequestBuilderInternal instantiates a new CheckRequestBuilder and sets the default values.

func (*CheckRequestBuilder) Post

Post checks whether a recipient is blocked by an active Leadping suppression entry before sending messages or placing calls through the selected channel. returns a SuppressionCheckResultable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code

func (*CheckRequestBuilder) ToPostRequestInformation

ToPostRequestInformation checks whether a recipient is blocked by an active Leadping suppression entry before sending messages or placing calls through the selected channel. returns a *RequestInformation when successful

func (*CheckRequestBuilder) WithUrl

func (m *CheckRequestBuilder) WithUrl(rawUrl string) *CheckRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *CheckRequestBuilder when successful

type ReleaseRequestBuilder

ReleaseRequestBuilder builds and executes requests for operations under \suppressions\release

func NewReleaseRequestBuilder

NewReleaseRequestBuilder instantiates a new ReleaseRequestBuilder and sets the default values.

func NewReleaseRequestBuilderInternal

func NewReleaseRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ReleaseRequestBuilder

NewReleaseRequestBuilderInternal instantiates a new ReleaseRequestBuilder and sets the default values.

func (*ReleaseRequestBuilder) Post

Post releases an active Leadping suppression entry so a recipient can be contacted again, returning the updated suppression record when available. returns a SuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code

func (*ReleaseRequestBuilder) ToPostRequestInformation

ToPostRequestInformation releases an active Leadping suppression entry so a recipient can be contacted again, returning the updated suppression record when available. returns a *RequestInformation when successful

func (*ReleaseRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ReleaseRequestBuilder when successful

type SuppressionsItemRequestBuilder added in v1.0.28

SuppressionsItemRequestBuilder builds and executes requests for operations under \suppressions\{id}

func NewSuppressionsItemRequestBuilder added in v1.0.28

NewSuppressionsItemRequestBuilder instantiates a new SuppressionsItemRequestBuilder and sets the default values.

func NewSuppressionsItemRequestBuilderInternal added in v1.0.28

func NewSuppressionsItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SuppressionsItemRequestBuilder

NewSuppressionsItemRequestBuilderInternal instantiates a new SuppressionsItemRequestBuilder and sets the default values.

func (*SuppressionsItemRequestBuilder) Get added in v1.0.28

Get returns one suppression entry for the current organization, including its recipient, channel, reason, status, and audit timestamps. returns a SuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code

func (*SuppressionsItemRequestBuilder) ToGetRequestInformation added in v1.0.28

ToGetRequestInformation returns one suppression entry for the current organization, including its recipient, channel, reason, status, and audit timestamps. returns a *RequestInformation when successful

func (*SuppressionsItemRequestBuilder) WithUrl added in v1.0.28

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SuppressionsItemRequestBuilder when successful

type SuppressionsRequestBuilder

SuppressionsRequestBuilder builds and executes requests for operations under \suppressions

func NewSuppressionsRequestBuilder

NewSuppressionsRequestBuilder instantiates a new SuppressionsRequestBuilder and sets the default values.

func NewSuppressionsRequestBuilderInternal

func NewSuppressionsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SuppressionsRequestBuilder

NewSuppressionsRequestBuilderInternal instantiates a new SuppressionsRequestBuilder and sets the default values.

func (*SuppressionsRequestBuilder) All added in v1.0.28

All the all property returns a *AllRequestBuilder when successful

func (*SuppressionsRequestBuilder) ById added in v1.0.28

ById gets an item from the github.com/leadpingai/leadping-go.suppressions.item collection returns a *SuppressionsItemRequestBuilder when successful

func (*SuppressionsRequestBuilder) Check

Check the check property returns a *CheckRequestBuilder when successful

func (*SuppressionsRequestBuilder) Post

Post creates or reactivates a Leadping suppression entry that blocks future outreach to a recipient across the selected communication channel. returns a SuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code

func (*SuppressionsRequestBuilder) Release

Release the release property returns a *ReleaseRequestBuilder when successful

func (*SuppressionsRequestBuilder) ToPostRequestInformation

ToPostRequestInformation creates or reactivates a Leadping suppression entry that blocks future outreach to a recipient across the selected communication channel. returns a *RequestInformation when successful

func (*SuppressionsRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SuppressionsRequestBuilder when successful

Jump to