telephony

package
v1.0.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LoginRequestBuilder

LoginRequestBuilder builds and executes requests for operations under \telephony\login

func NewLoginRequestBuilder

NewLoginRequestBuilder instantiates a new LoginRequestBuilder and sets the default values.

func NewLoginRequestBuilderInternal

func NewLoginRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *LoginRequestBuilder

NewLoginRequestBuilderInternal instantiates a new LoginRequestBuilder and sets the default values.

func (*LoginRequestBuilder) Post

Post generates a Leadping WebRTC login token so authenticated agents can connect to telephony services and place or receive browser-based calls. returns a TelephonyLoginResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code

func (*LoginRequestBuilder) ToPostRequestInformation

ToPostRequestInformation generates a Leadping WebRTC login token so authenticated agents can connect to telephony services and place or receive browser-based calls. returns a *RequestInformation when successful

func (*LoginRequestBuilder) WithUrl

func (m *LoginRequestBuilder) WithUrl(rawUrl string) *LoginRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *LoginRequestBuilder when successful

type TelephonyRequestBuilder

TelephonyRequestBuilder builds and executes requests for operations under \telephony

func NewTelephonyRequestBuilder

NewTelephonyRequestBuilder instantiates a new TelephonyRequestBuilder and sets the default values.

func NewTelephonyRequestBuilderInternal

func NewTelephonyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *TelephonyRequestBuilder

NewTelephonyRequestBuilderInternal instantiates a new TelephonyRequestBuilder and sets the default values.

func (*TelephonyRequestBuilder) Login

Login the login property returns a *LoginRequestBuilder when successful

Jump to