transactions

package
v1.0.22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AllMyRequestBuilder

AllMyRequestBuilder builds and executes requests for operations under \transactions\all\my

func NewAllMyRequestBuilder

NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.

func NewAllMyRequestBuilderInternal

func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder

NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.

func (*AllMyRequestBuilder) Post

Post lists current-user transactions with paging, sorting, and filters for wallet events, billing history, and reconciliation. returns a PagedResultOfTransactionTableRowable when successful returns a ProblemDetails error when the service returns a 401 status code

func (*AllMyRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists current-user transactions with paging, sorting, and filters for wallet events, billing history, and reconciliation. returns a *RequestInformation when successful

func (*AllMyRequestBuilder) WithUrl

func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful

type AllMyRequestBuilderPostQueryParameters added in v1.0.12

type AllMyRequestBuilderPostQueryParameters struct {
	EndAt   *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"endAt\""
	StartAt *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"startAt\""
}

AllMyRequestBuilderPostQueryParameters lists current-user transactions with paging, sorting, and filters for wallet events, billing history, and reconciliation.

type AllRequestBuilder

AllRequestBuilder builds and executes requests for operations under \transactions\all

func NewAllRequestBuilder

NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.

func NewAllRequestBuilderInternal

func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder

NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.

func (*AllRequestBuilder) My

My the my property returns a *AllMyRequestBuilder when successful

type TransactionsItemRequestBuilder

TransactionsItemRequestBuilder builds and executes requests for operations under \transactions\{id}

func NewTransactionsItemRequestBuilder

NewTransactionsItemRequestBuilder instantiates a new TransactionsItemRequestBuilder and sets the default values.

func NewTransactionsItemRequestBuilderInternal

func NewTransactionsItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *TransactionsItemRequestBuilder

NewTransactionsItemRequestBuilderInternal instantiates a new TransactionsItemRequestBuilder and sets the default values.

func (*TransactionsItemRequestBuilder) Get

Get returns one transaction visible to the current user, including amount, status, wallet context, and billing metadata. returns a TransactionResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code

func (*TransactionsItemRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns one transaction visible to the current user, including amount, status, wallet context, and billing metadata. returns a *RequestInformation when successful

func (*TransactionsItemRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *TransactionsItemRequestBuilder when successful

type TransactionsRequestBuilder

TransactionsRequestBuilder builds and executes requests for operations under \transactions

func NewTransactionsRequestBuilder

NewTransactionsRequestBuilder instantiates a new TransactionsRequestBuilder and sets the default values.

func NewTransactionsRequestBuilderInternal

func NewTransactionsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *TransactionsRequestBuilder

NewTransactionsRequestBuilderInternal instantiates a new TransactionsRequestBuilder and sets the default values.

func (*TransactionsRequestBuilder) All

All the all property returns a *AllRequestBuilder when successful

func (*TransactionsRequestBuilder) ById

ById gets an item from the github.com/leadpingai/leadping-go.transactions.item collection returns a *TransactionsItemRequestBuilder when successful

Jump to