Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllMyRequestBuilder ¶
type AllMyRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllMyRequestBuilder builds and executes requests for operations under \usage\all\my
func NewAllMyRequestBuilder ¶
func NewAllMyRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.
func NewAllMyRequestBuilderInternal ¶
func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.
func (*AllMyRequestBuilder) Post ¶
func (m *AllMyRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.PagedResultOfUsageLedgerTableRowable, error)
Post lists current-organization usage ledger entries with paging, sorting, and filters for messaging, billing, and wallet review. returns a PagedResultOfUsageLedgerTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code
func (*AllMyRequestBuilder) ToPostRequestInformation ¶
func (m *AllMyRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation lists current-organization usage ledger entries with paging, sorting, and filters for messaging, billing, and wallet review. returns a *RequestInformation when successful
func (*AllMyRequestBuilder) WithUrl ¶
func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful
type AllRequestBuilder ¶
type AllRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllRequestBuilder builds and executes requests for operations under \usage\all
func NewAllRequestBuilder ¶
func NewAllRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.
func NewAllRequestBuilderInternal ¶
func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.
func (*AllRequestBuilder) My ¶
func (m *AllRequestBuilder) My() *AllMyRequestBuilder
My the my property returns a *AllMyRequestBuilder when successful
type SummaryMyRequestBuilder ¶
type SummaryMyRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
SummaryMyRequestBuilder builds and executes requests for operations under \usage\summary\my
func NewSummaryMyRequestBuilder ¶
func NewSummaryMyRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SummaryMyRequestBuilder
NewSummaryMyRequestBuilder instantiates a new SummaryMyRequestBuilder and sets the default values.
func NewSummaryMyRequestBuilderInternal ¶
func NewSummaryMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SummaryMyRequestBuilder
NewSummaryMyRequestBuilderInternal instantiates a new SummaryMyRequestBuilder and sets the default values.
func (*SummaryMyRequestBuilder) Get ¶
func (m *SummaryMyRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[SummaryMyRequestBuilderGetQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UsageSummaryResponseable, error)
Get returns current-organization usage totals for the active billing period, including spend, limits, and event summary data. returns a UsageSummaryResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code
func (*SummaryMyRequestBuilder) ToGetRequestInformation ¶
func (m *SummaryMyRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[SummaryMyRequestBuilderGetQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns current-organization usage totals for the active billing period, including spend, limits, and event summary data. returns a *RequestInformation when successful
func (*SummaryMyRequestBuilder) WithUrl ¶
func (m *SummaryMyRequestBuilder) WithUrl(rawUrl string) *SummaryMyRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SummaryMyRequestBuilder when successful
type SummaryMyRequestBuilderGetQueryParameters ¶
type SummaryMyRequestBuilderGetQueryParameters struct {
// The period end.
PeriodEnd *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"periodEnd\""
// The period start.
PeriodStart *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"periodStart\""
}
SummaryMyRequestBuilderGetQueryParameters returns current-organization usage totals for the active billing period, including spend, limits, and event summary data.
type SummaryRequestBuilder ¶
type SummaryRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
SummaryRequestBuilder builds and executes requests for operations under \usage\summary
func NewSummaryRequestBuilder ¶
func NewSummaryRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SummaryRequestBuilder
NewSummaryRequestBuilder instantiates a new SummaryRequestBuilder and sets the default values.
func NewSummaryRequestBuilderInternal ¶
func NewSummaryRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SummaryRequestBuilder
NewSummaryRequestBuilderInternal instantiates a new SummaryRequestBuilder and sets the default values.
func (*SummaryRequestBuilder) My ¶
func (m *SummaryRequestBuilder) My() *SummaryMyRequestBuilder
My the my property returns a *SummaryMyRequestBuilder when successful
type UsageRequestBuilder ¶
type UsageRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
UsageRequestBuilder builds and executes requests for operations under \usage
func NewUsageRequestBuilder ¶
func NewUsageRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UsageRequestBuilder
NewUsageRequestBuilder instantiates a new UsageRequestBuilder and sets the default values.
func NewUsageRequestBuilderInternal ¶
func NewUsageRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UsageRequestBuilder
NewUsageRequestBuilderInternal instantiates a new UsageRequestBuilder and sets the default values.
func (*UsageRequestBuilder) All ¶
func (m *UsageRequestBuilder) All() *AllRequestBuilder
All the all property returns a *AllRequestBuilder when successful
func (*UsageRequestBuilder) Summary ¶
func (m *UsageRequestBuilder) Summary() *SummaryRequestBuilder
Summary the summary property returns a *SummaryRequestBuilder when successful