users

package
v1.0.45 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ChangeBillingPlanRequestBuilder

ChangeBillingPlanRequestBuilder builds and executes requests for operations under \users\change-billing-plan

func NewChangeBillingPlanRequestBuilder

NewChangeBillingPlanRequestBuilder instantiates a new ChangeBillingPlanRequestBuilder and sets the default values.

func NewChangeBillingPlanRequestBuilderInternal

func NewChangeBillingPlanRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ChangeBillingPlanRequestBuilder

NewChangeBillingPlanRequestBuilderInternal instantiates a new ChangeBillingPlanRequestBuilder and sets the default values.

func (*ChangeBillingPlanRequestBuilder) Put

Put changes the current user's billing plan selection, updating account billing state and plan-specific capabilities. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ChangeBillingPlanRequestBuilder) ToPutRequestInformation

ToPutRequestInformation changes the current user's billing plan selection, updating account billing state and plan-specific capabilities. returns a *RequestInformation when successful

func (*ChangeBillingPlanRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ChangeBillingPlanRequestBuilder when successful

type ComplianceRequestBuilder

ComplianceRequestBuilder builds and executes requests for operations under \users\compliance

func NewComplianceRequestBuilder

NewComplianceRequestBuilder instantiates a new ComplianceRequestBuilder and sets the default values.

func NewComplianceRequestBuilderInternal

func NewComplianceRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ComplianceRequestBuilder

NewComplianceRequestBuilderInternal instantiates a new ComplianceRequestBuilder and sets the default values.

func (*ComplianceRequestBuilder) Put

Put updates current-user compliance settings used for messaging eligibility, billing readiness, and organization account setup. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 429 status code

func (*ComplianceRequestBuilder) ToPutRequestInformation

ToPutRequestInformation updates current-user compliance settings used for messaging eligibility, billing readiness, and organization account setup. returns a *RequestInformation when successful

func (*ComplianceRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ComplianceRequestBuilder when successful

type MePaymentmethodRequestBuilder

MePaymentmethodRequestBuilder builds and executes requests for operations under \users\me\paymentmethod

func NewMePaymentmethodRequestBuilder

NewMePaymentmethodRequestBuilder instantiates a new MePaymentmethodRequestBuilder and sets the default values.

func NewMePaymentmethodRequestBuilderInternal

func NewMePaymentmethodRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MePaymentmethodRequestBuilder

NewMePaymentmethodRequestBuilderInternal instantiates a new MePaymentmethodRequestBuilder and sets the default values.

func (*MePaymentmethodRequestBuilder) Get

Get returns the current user's default payment method details for billing displays and account payment management. returns a StripePaymentMethodResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 429 status code

func (*MePaymentmethodRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns the current user's default payment method details for billing displays and account payment management. returns a *RequestInformation when successful

func (*MePaymentmethodRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *MePaymentmethodRequestBuilder when successful

type MeRequestBuilder

MeRequestBuilder builds and executes requests for operations under \users\me

func NewMeRequestBuilder

NewMeRequestBuilder instantiates a new MeRequestBuilder and sets the default values.

func NewMeRequestBuilderInternal

func NewMeRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MeRequestBuilder

NewMeRequestBuilderInternal instantiates a new MeRequestBuilder and sets the default values.

func (*MeRequestBuilder) Get

Get returns the current user's profile, roles, organization context, billing state, and compliance settings for portal sessions. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code

func (*MeRequestBuilder) Paymentmethod

func (m *MeRequestBuilder) Paymentmethod() *MePaymentmethodRequestBuilder

Paymentmethod the paymentmethod property returns a *MePaymentmethodRequestBuilder when successful

func (*MeRequestBuilder) Put

Put updates the current user's profile fields, contact details, preferences, or organization context used across Leadping. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 429 status code

func (*MeRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns the current user's profile, roles, organization context, billing state, and compliance settings for portal sessions. returns a *RequestInformation when successful

func (*MeRequestBuilder) ToPutRequestInformation

ToPutRequestInformation updates the current user's profile fields, contact details, preferences, or organization context used across Leadping. returns a *RequestInformation when successful

func (*MeRequestBuilder) WithUrl

func (m *MeRequestBuilder) WithUrl(rawUrl string) *MeRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *MeRequestBuilder when successful

type UsersRequestBuilder

UsersRequestBuilder builds and executes requests for operations under \users

func NewUsersRequestBuilder

NewUsersRequestBuilder instantiates a new UsersRequestBuilder and sets the default values.

func NewUsersRequestBuilderInternal

func NewUsersRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UsersRequestBuilder

NewUsersRequestBuilderInternal instantiates a new UsersRequestBuilder and sets the default values.

func (*UsersRequestBuilder) ChangeBillingPlan

func (m *UsersRequestBuilder) ChangeBillingPlan() *ChangeBillingPlanRequestBuilder

ChangeBillingPlan the changeBillingPlan property returns a *ChangeBillingPlanRequestBuilder when successful

func (*UsersRequestBuilder) Compliance

Compliance the compliance property returns a *ComplianceRequestBuilder when successful

func (*UsersRequestBuilder) Me

Me the me property returns a *MeRequestBuilder when successful

Jump to