wellknown

package
v1.0.46 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AgentCardJsonRequestBuilder

AgentCardJsonRequestBuilder builds and executes requests for operations under \.well-known\agent-card.json

func NewAgentCardJsonRequestBuilder

NewAgentCardJsonRequestBuilder instantiates a new AgentCardJsonRequestBuilder and sets the default values.

func NewAgentCardJsonRequestBuilderInternal

func NewAgentCardJsonRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AgentCardJsonRequestBuilder

NewAgentCardJsonRequestBuilderInternal instantiates a new AgentCardJsonRequestBuilder and sets the default values.

func (*AgentCardJsonRequestBuilder) Get

Get returns Leadping's public A2A Agent Card, including protocol capabilities, authentication requirements, input and output modes, and supported skills. returns a []byte when successful returns a ProblemDetails error when the service returns a 429 status code

func (*AgentCardJsonRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns Leadping's public A2A Agent Card, including protocol capabilities, authentication requirements, input and output modes, and supported skills. returns a *RequestInformation when successful

func (*AgentCardJsonRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AgentCardJsonRequestBuilder when successful

type WellKnownRequestBuilder

WellKnownRequestBuilder builds and executes requests for operations under \.well-known

func NewWellKnownRequestBuilder

NewWellKnownRequestBuilder instantiates a new WellKnownRequestBuilder and sets the default values.

func NewWellKnownRequestBuilderInternal

func NewWellKnownRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *WellKnownRequestBuilder

NewWellKnownRequestBuilderInternal instantiates a new WellKnownRequestBuilder and sets the default values.

func (*WellKnownRequestBuilder) AgentCardJson

AgentCardJson the agentCardJson property returns a *AgentCardJsonRequestBuilder when successful

Jump to