Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ContactRequestBuilder ¶
type ContactRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ContactRequestBuilder builds and executes requests for operations under \contact
func NewContactRequestBuilder ¶
func NewContactRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ContactRequestBuilder
NewContactRequestBuilder instantiates a new ContactRequestBuilder and sets the default values.
func NewContactRequestBuilderInternal ¶
func NewContactRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ContactRequestBuilder
NewContactRequestBuilderInternal instantiates a new ContactRequestBuilder and sets the default values.
func (*ContactRequestBuilder) Post ¶
func (m *ContactRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.ContactRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.ContactResponseable, error)
Post submits a public contact request to Leadping support, capturing sender details and message content without requiring authentication. returns a ContactResponseable when successful returns a ProblemDetails error when the service returns a 400 status code
func (*ContactRequestBuilder) ToPostRequestInformation ¶
func (m *ContactRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.ContactRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation submits a public contact request to Leadping support, capturing sender details and message content without requiring authentication. returns a *RequestInformation when successful
func (*ContactRequestBuilder) WithUrl ¶
func (m *ContactRequestBuilder) WithUrl(rawUrl string) *ContactRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ContactRequestBuilder when successful