Documentation
¶
Index ¶
- func CreateItemArchivePostRequestBodyFromDiscriminatorValue(...) (i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, ...)
- type AllMyRequestBuilder
- type AllMyRequestBuilderPostQueryParameters
- type AllRequestBuilder
- type IntakeRequestBuilder
- func (m *IntakeRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *IntakeRequestBuilder) Post(ctx context.Context, ...) (...)
- func (m *IntakeRequestBuilder) ToGetRequestInformation(ctx context.Context, ...) (...)
- func (m *IntakeRequestBuilder) ToPostRequestInformation(ctx context.Context, ...) (...)
- func (m *IntakeRequestBuilder) WithUrl(rawUrl string) *IntakeRequestBuilder
- type IntakeRequestBuilderGetQueryParameters
- type IntakeRequestBuilderPostQueryParameters
- type ItemArchivePostRequestBody
- type ItemArchivePostRequestBodyable
- type ItemArchiveRequestBuilder
- func (m *ItemArchiveRequestBuilder) Post(ctx context.Context, body ItemArchivePostRequestBodyable, ...) (...)
- func (m *ItemArchiveRequestBuilder) ToPostRequestInformation(ctx context.Context, body ItemArchivePostRequestBodyable, ...) (...)
- func (m *ItemArchiveRequestBuilder) WithUrl(rawUrl string) *ItemArchiveRequestBuilder
- type ItemRequestBuilder
- func (m *ItemRequestBuilder) Archive() *ItemArchiveRequestBuilder
- func (m *ItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *ItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *ItemRequestBuilder) Put(ctx context.Context, ...) (...)
- func (m *ItemRequestBuilder) Status() *ItemStatusRequestBuilder
- func (m *ItemRequestBuilder) StatusHistory() *ItemStatusHistoryRequestBuilder
- func (m *ItemRequestBuilder) Tags() *ItemTagsRequestBuilder
- func (m *ItemRequestBuilder) ToDeleteRequestInformation(ctx context.Context, ...) (...)
- func (m *ItemRequestBuilder) ToGetRequestInformation(ctx context.Context, ...) (...)
- func (m *ItemRequestBuilder) ToPutRequestInformation(ctx context.Context, ...) (...)
- func (m *ItemRequestBuilder) Unarchive() *ItemUnarchiveRequestBuilder
- func (m *ItemRequestBuilder) WithUrl(rawUrl string) *ItemRequestBuilder
- func (m *ItemRequestBuilder) WorkflowStatus() *ItemWorkflowStatusRequestBuilder
- type ItemStatusHistoryExportRequestBuilder
- type ItemStatusHistoryRequestBuilder
- func (m *ItemStatusHistoryRequestBuilder) Export() *ItemStatusHistoryExportRequestBuilder
- func (m *ItemStatusHistoryRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *ItemStatusHistoryRequestBuilder) ToGetRequestInformation(ctx context.Context, ...) (...)
- func (m *ItemStatusHistoryRequestBuilder) WithUrl(rawUrl string) *ItemStatusHistoryRequestBuilder
- type ItemStatusRequestBuilder
- type ItemTagsRequestBuilder
- func (m *ItemTagsRequestBuilder) ByTagId(tagId string) *ItemTagsWithTagItemRequestBuilder
- func (m *ItemTagsRequestBuilder) Post(ctx context.Context, ...) (...)
- func (m *ItemTagsRequestBuilder) Put(ctx context.Context, ...) (...)
- func (m *ItemTagsRequestBuilder) ToPostRequestInformation(ctx context.Context, ...) (...)
- func (m *ItemTagsRequestBuilder) ToPutRequestInformation(ctx context.Context, ...) (...)
- func (m *ItemTagsRequestBuilder) WithUrl(rawUrl string) *ItemTagsRequestBuilder
- type ItemTagsWithTagItemRequestBuilder
- type ItemUnarchiveRequestBuilder
- type ItemWorkflowStatusRequestBuilder
- type LeadsRequestBuilder
- func (m *LeadsRequestBuilder) All() *AllRequestBuilder
- func (m *LeadsRequestBuilder) ById(id string) *ItemRequestBuilder
- func (m *LeadsRequestBuilder) Intake() *IntakeRequestBuilder
- func (m *LeadsRequestBuilder) Post(ctx context.Context, ...) (...)
- func (m *LeadsRequestBuilder) ToPostRequestInformation(ctx context.Context, ...) (...)
- func (m *LeadsRequestBuilder) WithUrl(rawUrl string) *LeadsRequestBuilder
- type LeadsRequestBuilderPostQueryParameters
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateItemArchivePostRequestBodyFromDiscriminatorValue ¶
func CreateItemArchivePostRequestBodyFromDiscriminatorValue(parseNode i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) (i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, error)
CreateItemArchivePostRequestBodyFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value returns a Parsable when successful
Types ¶
type AllMyRequestBuilder ¶
type AllMyRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllMyRequestBuilder builds and executes requests for operations under \leads\all\my
func NewAllMyRequestBuilder ¶
func NewAllMyRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.
func NewAllMyRequestBuilderInternal ¶
func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.
func (*AllMyRequestBuilder) Post ¶
func (m *AllMyRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[AllMyRequestBuilderPostQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.PagedResultOfLeadTableRowable, error)
Post lists leads visible to the current user with paging, sorting, filters, tags, and archive status for pipeline review. returns a PagedResultOfLeadTableRowable when successful returns a ProblemDetails error when the service returns a 401 status code
func (*AllMyRequestBuilder) ToPostRequestInformation ¶
func (m *AllMyRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[AllMyRequestBuilderPostQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation lists leads visible to the current user with paging, sorting, filters, tags, and archive status for pipeline review. returns a *RequestInformation when successful
func (*AllMyRequestBuilder) WithUrl ¶
func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful
type AllMyRequestBuilderPostQueryParameters ¶
type AllMyRequestBuilderPostQueryParameters struct {
// Optional filter selecting active, archived, or all leads.
ArchiveFilter *string "uriparametername:\"archiveFilter\""
// Optional tag identifiers used to filter the lead list.
TagIds []string "uriparametername:\"tagIds\""
// Whether a lead must contain every supplied tag instead of any supplied tag.
TagMatchAll *bool "uriparametername:\"tagMatchAll\""
// Whether to include only leads that have no tags.
Untagged *bool "uriparametername:\"untagged\""
}
AllMyRequestBuilderPostQueryParameters lists leads visible to the current user with paging, sorting, filters, tags, and archive status for pipeline review.
type AllRequestBuilder ¶
type AllRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllRequestBuilder builds and executes requests for operations under \leads\all
func NewAllRequestBuilder ¶
func NewAllRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.
func NewAllRequestBuilderInternal ¶
func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.
func (*AllRequestBuilder) My ¶
func (m *AllRequestBuilder) My() *AllMyRequestBuilder
My the my property returns a *AllMyRequestBuilder when successful
type IntakeRequestBuilder ¶
type IntakeRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
IntakeRequestBuilder builds and executes requests for operations under \leads\intake
func NewIntakeRequestBuilder ¶
func NewIntakeRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *IntakeRequestBuilder
NewIntakeRequestBuilder instantiates a new IntakeRequestBuilder and sets the default values.
func NewIntakeRequestBuilderInternal ¶
func NewIntakeRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *IntakeRequestBuilder
NewIntakeRequestBuilderInternal instantiates a new IntakeRequestBuilder and sets the default values.
func (*IntakeRequestBuilder) Get ¶
func (m *IntakeRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[IntakeRequestBuilderGetQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Get creates a source-authenticated lead from query parameters, supporting simple form posts, tracking metadata, and follow-up automation. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code
func (*IntakeRequestBuilder) Post ¶
func (m *IntakeRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadIntakeRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[IntakeRequestBuilderPostQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Post creates a source-authenticated lead from a flat intake payload, capturing contact fields, metadata, and automation-ready lead details. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code
func (*IntakeRequestBuilder) ToGetRequestInformation ¶
func (m *IntakeRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[IntakeRequestBuilderGetQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation creates a source-authenticated lead from query parameters, supporting simple form posts, tracking metadata, and follow-up automation. returns a *RequestInformation when successful
func (*IntakeRequestBuilder) ToPostRequestInformation ¶
func (m *IntakeRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadIntakeRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[IntakeRequestBuilderPostQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation creates a source-authenticated lead from a flat intake payload, capturing contact fields, metadata, and automation-ready lead details. returns a *RequestInformation when successful
func (*IntakeRequestBuilder) WithUrl ¶
func (m *IntakeRequestBuilder) WithUrl(rawUrl string) *IntakeRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *IntakeRequestBuilder when successful
type IntakeRequestBuilderGetQueryParameters ¶
type IntakeRequestBuilderGetQueryParameters struct {
// First street address line submitted by the lead intake source.
Address1 *string
// Second street address line submitted by the lead intake source.
Address2 *string
// Lead birth date used for demographic matching and insurance intake workflows.
BirthDate *i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.DateOnly
// City for the lead or organization postal address.
City *string
// Lead date of birth supplied by intake sources and normalized into the lead profile.
DateOfBirth *i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.DateOnly
// Direct-post price supplied by the lead source during intake.
DirectPostPrice *string
// Email address for the person represented by this lead intake request.
Email *string
// External system identifier used to reconcile this lead intake request across integrations.
ExternalId *string
// First name of the lead, user, or contact represented by this lead intake request.
FirstName *string
// Lead gender supplied by intake sources and normalized when possible.
Gender *string
// Landing page URL where the lead submitted their information.
LandingPage *string
// Last name of the lead, user, or contact represented by this lead intake request.
LastName *string
// Phone details for the lead, user, or organization represented by this lead intake request.
Phone *string
// Source-provided phone type, such as mobile, landline, or VoIP, used during lead intake normalization.
PhoneType *string
// Postal code for the lead or organization address.
PostalCode *string
// Lead price or transaction price supplied to the Leadping API.
Price *string
// Product or offer associated with the lead or source.
Product *string
// Referring page or traffic source that sent the lead into Leadping.
Referrer *string
// Seller-provided lead identifier used to deduplicate and reconcile lead delivery.
SellerLeadId *string
// Alternate seller-provided lead identifier used during intake normalization.
SellerLeadIdentifier *string
// The Leadping source key supplied as a query string parameter, or omitted when supplied as Authorization: Bearer lp_src_...
SourceKey *string "uriparametername:\"sourceKey\""
// Source-provided key-value metadata retained for lead attribution and integration troubleshooting.
SourceMetadata *string
// State, province, or region for the lead or organization postal address.
State *string
// Affiliate or publisher sub ID captured for lead attribution.
SubId *string
// Tag IDs assigned to or filtered against this lead.
TagIds []string
// Tag names assigned to this lead when matching existing tags by name.
TagNames []string
// TrustedForm certificate URL used as proof of consumer consent.
TrustedFormUrl *string
// UTM campaign parameter captured for lead attribution reporting.
UtmCampaign *string
// UTM content parameter captured for lead attribution reporting.
UtmContent *string
// UTM medium parameter captured for lead attribution reporting.
UtmMedium *string
// UTM source parameter captured for lead attribution reporting.
UtmSource *string
// UTM term parameter captured for lead attribution reporting.
UtmTerm *string
// Industry vertical used for lead routing, compliance review, and reporting.
Vertical *string
// ZIP code submitted by the lead intake source.
Zip *string
}
IntakeRequestBuilderGetQueryParameters creates a source-authenticated lead from query parameters, supporting simple form posts, tracking metadata, and follow-up automation.
type IntakeRequestBuilderPostQueryParameters ¶
type IntakeRequestBuilderPostQueryParameters struct {
// The Leadping source key supplied as a query string parameter, or omitted when supplied as Authorization: Bearer lp_src_...
SourceKey *string "uriparametername:\"sourceKey\""
}
IntakeRequestBuilderPostQueryParameters creates a source-authenticated lead from a flat intake payload, capturing contact fields, metadata, and automation-ready lead details.
type ItemArchivePostRequestBody ¶
type ItemArchivePostRequestBody struct {
i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadArchiveRequest
}
ItemArchivePostRequestBody defines the fields clients can send when working with lead archive.
func NewItemArchivePostRequestBody ¶
func NewItemArchivePostRequestBody() *ItemArchivePostRequestBody
NewItemArchivePostRequestBody instantiates a new ItemArchivePostRequestBody and sets the default values.
func (*ItemArchivePostRequestBody) GetFieldDeserializers ¶
func (m *ItemArchivePostRequestBody) GetFieldDeserializers() map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error
GetFieldDeserializers the deserialization information for the current model returns a map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error) when successful
func (*ItemArchivePostRequestBody) Serialize ¶
func (m *ItemArchivePostRequestBody) Serialize(writer i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.SerializationWriter) error
Serialize serializes information the current object
type ItemArchivePostRequestBodyable ¶
type ItemArchivePostRequestBodyable interface {
i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadArchiveRequestable
i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable
}
type ItemArchiveRequestBuilder ¶
type ItemArchiveRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemArchiveRequestBuilder builds and executes requests for operations under \leads\{-id}\archive
func NewItemArchiveRequestBuilder ¶
func NewItemArchiveRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemArchiveRequestBuilder
NewItemArchiveRequestBuilder instantiates a new ItemArchiveRequestBuilder and sets the default values.
func NewItemArchiveRequestBuilderInternal ¶
func NewItemArchiveRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemArchiveRequestBuilder
NewItemArchiveRequestBuilderInternal instantiates a new ItemArchiveRequestBuilder and sets the default values.
func (*ItemArchiveRequestBuilder) Post ¶
func (m *ItemArchiveRequestBuilder) Post(ctx context.Context, body ItemArchivePostRequestBodyable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Post archives a lead without deleting history, removing it from active pipeline views while preserving communication and event records. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemArchiveRequestBuilder) ToPostRequestInformation ¶
func (m *ItemArchiveRequestBuilder) ToPostRequestInformation(ctx context.Context, body ItemArchivePostRequestBodyable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation archives a lead without deleting history, removing it from active pipeline views while preserving communication and event records. returns a *RequestInformation when successful
func (*ItemArchiveRequestBuilder) WithUrl ¶
func (m *ItemArchiveRequestBuilder) WithUrl(rawUrl string) *ItemArchiveRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemArchiveRequestBuilder when successful
type ItemRequestBuilder ¶ added in v1.0.29
type ItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemRequestBuilder builds and executes requests for operations under \leads\{-id}
func NewItemRequestBuilder ¶ added in v1.0.29
func NewItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemRequestBuilder
NewItemRequestBuilder instantiates a new ItemRequestBuilder and sets the default values.
func NewItemRequestBuilderInternal ¶ added in v1.0.29
func NewItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemRequestBuilder
NewItemRequestBuilderInternal instantiates a new ItemRequestBuilder and sets the default values.
func (*ItemRequestBuilder) Archive ¶ added in v1.0.29
func (m *ItemRequestBuilder) Archive() *ItemArchiveRequestBuilder
Archive the archive property returns a *ItemArchiveRequestBuilder when successful
func (*ItemRequestBuilder) Delete ¶ added in v1.0.29
func (m *ItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) error
Delete deletes a lead from the current organization when it should no longer appear in communication, routing, or event workflows. returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemRequestBuilder) Get ¶ added in v1.0.29
func (m *ItemRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Get returns one lead visible to the current user, including communication details, status, source, and follow-up context. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemRequestBuilder) Put ¶ added in v1.0.29
func (m *ItemRequestBuilder) Put(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Put updates lead details for the current organization, keeping contact data, status, source, and follow-up context current. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemRequestBuilder) Status ¶ added in v1.0.29
func (m *ItemRequestBuilder) Status() *ItemStatusRequestBuilder
Status the status property returns a *ItemStatusRequestBuilder when successful
func (*ItemRequestBuilder) StatusHistory ¶ added in v1.0.29
func (m *ItemRequestBuilder) StatusHistory() *ItemStatusHistoryRequestBuilder
StatusHistory the statusHistory property returns a *ItemStatusHistoryRequestBuilder when successful
func (*ItemRequestBuilder) Tags ¶ added in v1.0.29
func (m *ItemRequestBuilder) Tags() *ItemTagsRequestBuilder
Tags the tags property returns a *ItemTagsRequestBuilder when successful
func (*ItemRequestBuilder) ToDeleteRequestInformation ¶ added in v1.0.29
func (m *ItemRequestBuilder) ToDeleteRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToDeleteRequestInformation deletes a lead from the current organization when it should no longer appear in communication, routing, or event workflows. returns a *RequestInformation when successful
func (*ItemRequestBuilder) ToGetRequestInformation ¶ added in v1.0.29
func (m *ItemRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns one lead visible to the current user, including communication details, status, source, and follow-up context. returns a *RequestInformation when successful
func (*ItemRequestBuilder) ToPutRequestInformation ¶ added in v1.0.29
func (m *ItemRequestBuilder) ToPutRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPutRequestInformation updates lead details for the current organization, keeping contact data, status, source, and follow-up context current. returns a *RequestInformation when successful
func (*ItemRequestBuilder) Unarchive ¶ added in v1.0.29
func (m *ItemRequestBuilder) Unarchive() *ItemUnarchiveRequestBuilder
Unarchive the unarchive property returns a *ItemUnarchiveRequestBuilder when successful
func (*ItemRequestBuilder) WithUrl ¶ added in v1.0.29
func (m *ItemRequestBuilder) WithUrl(rawUrl string) *ItemRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemRequestBuilder when successful
func (*ItemRequestBuilder) WorkflowStatus ¶ added in v1.0.29
func (m *ItemRequestBuilder) WorkflowStatus() *ItemWorkflowStatusRequestBuilder
WorkflowStatus the workflowStatus property returns a *ItemWorkflowStatusRequestBuilder when successful
type ItemStatusHistoryExportRequestBuilder ¶ added in v1.0.29
type ItemStatusHistoryExportRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemStatusHistoryExportRequestBuilder builds and executes requests for operations under \leads\{-id}\status-history\export
func NewItemStatusHistoryExportRequestBuilder ¶ added in v1.0.29
func NewItemStatusHistoryExportRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemStatusHistoryExportRequestBuilder
NewItemStatusHistoryExportRequestBuilder instantiates a new ItemStatusHistoryExportRequestBuilder and sets the default values.
func NewItemStatusHistoryExportRequestBuilderInternal ¶ added in v1.0.29
func NewItemStatusHistoryExportRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemStatusHistoryExportRequestBuilder
NewItemStatusHistoryExportRequestBuilderInternal instantiates a new ItemStatusHistoryExportRequestBuilder and sets the default values.
func (*ItemStatusHistoryExportRequestBuilder) Get ¶ added in v1.0.29
func (m *ItemStatusHistoryExportRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadStatusChangeExportResponseable, error)
Get exports lead status change data for one lead, packaging outcome history for reporting, audit review, or handoff workflows. returns a LeadStatusChangeExportResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemStatusHistoryExportRequestBuilder) ToGetRequestInformation ¶ added in v1.0.29
func (m *ItemStatusHistoryExportRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation exports lead status change data for one lead, packaging outcome history for reporting, audit review, or handoff workflows. returns a *RequestInformation when successful
func (*ItemStatusHistoryExportRequestBuilder) WithUrl ¶ added in v1.0.29
func (m *ItemStatusHistoryExportRequestBuilder) WithUrl(rawUrl string) *ItemStatusHistoryExportRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemStatusHistoryExportRequestBuilder when successful
type ItemStatusHistoryRequestBuilder ¶ added in v1.0.29
type ItemStatusHistoryRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemStatusHistoryRequestBuilder builds and executes requests for operations under \leads\{-id}\status-history
func NewItemStatusHistoryRequestBuilder ¶ added in v1.0.29
func NewItemStatusHistoryRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemStatusHistoryRequestBuilder
NewItemStatusHistoryRequestBuilder instantiates a new ItemStatusHistoryRequestBuilder and sets the default values.
func NewItemStatusHistoryRequestBuilderInternal ¶ added in v1.0.29
func NewItemStatusHistoryRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemStatusHistoryRequestBuilder
NewItemStatusHistoryRequestBuilderInternal instantiates a new ItemStatusHistoryRequestBuilder and sets the default values.
func (*ItemStatusHistoryRequestBuilder) Export ¶ added in v1.0.29
func (m *ItemStatusHistoryRequestBuilder) Export() *ItemStatusHistoryExportRequestBuilder
Export the export property returns a *ItemStatusHistoryExportRequestBuilder when successful
func (*ItemStatusHistoryRequestBuilder) Get ¶ added in v1.0.29
func (m *ItemStatusHistoryRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) ([]i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadStatusChangeResponseable, error)
Get lists lead status change outcome history for one lead, including prior outcomes, notes, follow-up context, timestamps, and actor details used for audit review. returns a []LeadStatusChangeResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemStatusHistoryRequestBuilder) ToGetRequestInformation ¶ added in v1.0.29
func (m *ItemStatusHistoryRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation lists lead status change outcome history for one lead, including prior outcomes, notes, follow-up context, timestamps, and actor details used for audit review. returns a *RequestInformation when successful
func (*ItemStatusHistoryRequestBuilder) WithUrl ¶ added in v1.0.29
func (m *ItemStatusHistoryRequestBuilder) WithUrl(rawUrl string) *ItemStatusHistoryRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemStatusHistoryRequestBuilder when successful
type ItemStatusRequestBuilder ¶ added in v1.0.29
type ItemStatusRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemStatusRequestBuilder builds and executes requests for operations under \leads\{-id}\status
func NewItemStatusRequestBuilder ¶ added in v1.0.29
func NewItemStatusRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemStatusRequestBuilder
NewItemStatusRequestBuilder instantiates a new ItemStatusRequestBuilder and sets the default values.
func NewItemStatusRequestBuilderInternal ¶ added in v1.0.29
func NewItemStatusRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemStatusRequestBuilder
NewItemStatusRequestBuilderInternal instantiates a new ItemStatusRequestBuilder and sets the default values.
func (*ItemStatusRequestBuilder) Put ¶ added in v1.0.29
func (m *ItemStatusRequestBuilder) Put(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadStatusChangeRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadStatusChangeResponseable, error)
Put sets the lead's current structured status and records the change for audit, automation, and reporting. returns a LeadStatusChangeResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemStatusRequestBuilder) ToPutRequestInformation ¶ added in v1.0.29
func (m *ItemStatusRequestBuilder) ToPutRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadStatusChangeRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPutRequestInformation sets the lead's current structured status and records the change for audit, automation, and reporting. returns a *RequestInformation when successful
func (*ItemStatusRequestBuilder) WithUrl ¶ added in v1.0.29
func (m *ItemStatusRequestBuilder) WithUrl(rawUrl string) *ItemStatusRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemStatusRequestBuilder when successful
type ItemTagsRequestBuilder ¶
type ItemTagsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemTagsRequestBuilder builds and executes requests for operations under \leads\{-id}\tags
func NewItemTagsRequestBuilder ¶
func NewItemTagsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemTagsRequestBuilder
NewItemTagsRequestBuilder instantiates a new ItemTagsRequestBuilder and sets the default values.
func NewItemTagsRequestBuilderInternal ¶
func NewItemTagsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemTagsRequestBuilder
NewItemTagsRequestBuilderInternal instantiates a new ItemTagsRequestBuilder and sets the default values.
func (*ItemTagsRequestBuilder) ByTagId ¶
func (m *ItemTagsRequestBuilder) ByTagId(tagId string) *ItemTagsWithTagItemRequestBuilder
ByTagId gets an item from the github.com/leadpingai/leadping-go.leads.item.tags.item collection returns a *ItemTagsWithTagItemRequestBuilder when successful
func (*ItemTagsRequestBuilder) Post ¶
func (m *ItemTagsRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadTagsRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Post adds one or more current-organization tags to a lead so users can segment, filter, route, and review follow-up work. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemTagsRequestBuilder) Put ¶
func (m *ItemTagsRequestBuilder) Put(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadTagsRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Put replaces all tags on a lead with the supplied current-organization tags, keeping segmentation and routing labels in sync. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemTagsRequestBuilder) ToPostRequestInformation ¶
func (m *ItemTagsRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadTagsRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation adds one or more current-organization tags to a lead so users can segment, filter, route, and review follow-up work. returns a *RequestInformation when successful
func (*ItemTagsRequestBuilder) ToPutRequestInformation ¶
func (m *ItemTagsRequestBuilder) ToPutRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadTagsRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPutRequestInformation replaces all tags on a lead with the supplied current-organization tags, keeping segmentation and routing labels in sync. returns a *RequestInformation when successful
func (*ItemTagsRequestBuilder) WithUrl ¶
func (m *ItemTagsRequestBuilder) WithUrl(rawUrl string) *ItemTagsRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemTagsRequestBuilder when successful
type ItemTagsWithTagItemRequestBuilder ¶
type ItemTagsWithTagItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemTagsWithTagItemRequestBuilder builds and executes requests for operations under \leads\{-id}\tags\{tagId}
func NewItemTagsWithTagItemRequestBuilder ¶
func NewItemTagsWithTagItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemTagsWithTagItemRequestBuilder
NewItemTagsWithTagItemRequestBuilder instantiates a new ItemTagsWithTagItemRequestBuilder and sets the default values.
func NewItemTagsWithTagItemRequestBuilderInternal ¶
func NewItemTagsWithTagItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemTagsWithTagItemRequestBuilder
NewItemTagsWithTagItemRequestBuilderInternal instantiates a new ItemTagsWithTagItemRequestBuilder and sets the default values.
func (*ItemTagsWithTagItemRequestBuilder) Delete ¶
func (m *ItemTagsWithTagItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Delete removes one current-organization tag from a lead while leaving the lead record, other tags, and communication history intact. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemTagsWithTagItemRequestBuilder) ToDeleteRequestInformation ¶
func (m *ItemTagsWithTagItemRequestBuilder) ToDeleteRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToDeleteRequestInformation removes one current-organization tag from a lead while leaving the lead record, other tags, and communication history intact. returns a *RequestInformation when successful
func (*ItemTagsWithTagItemRequestBuilder) WithUrl ¶
func (m *ItemTagsWithTagItemRequestBuilder) WithUrl(rawUrl string) *ItemTagsWithTagItemRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemTagsWithTagItemRequestBuilder when successful
type ItemUnarchiveRequestBuilder ¶
type ItemUnarchiveRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemUnarchiveRequestBuilder builds and executes requests for operations under \leads\{-id}\unarchive
func NewItemUnarchiveRequestBuilder ¶
func NewItemUnarchiveRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemUnarchiveRequestBuilder
NewItemUnarchiveRequestBuilder instantiates a new ItemUnarchiveRequestBuilder and sets the default values.
func NewItemUnarchiveRequestBuilderInternal ¶
func NewItemUnarchiveRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemUnarchiveRequestBuilder
NewItemUnarchiveRequestBuilderInternal instantiates a new ItemUnarchiveRequestBuilder and sets the default values.
func (*ItemUnarchiveRequestBuilder) Post ¶
func (m *ItemUnarchiveRequestBuilder) Post(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Post restores an archived lead to active pipeline views so follow-up, communication, and routing workflows can resume. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemUnarchiveRequestBuilder) ToPostRequestInformation ¶
func (m *ItemUnarchiveRequestBuilder) ToPostRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation restores an archived lead to active pipeline views so follow-up, communication, and routing workflows can resume. returns a *RequestInformation when successful
func (*ItemUnarchiveRequestBuilder) WithUrl ¶
func (m *ItemUnarchiveRequestBuilder) WithUrl(rawUrl string) *ItemUnarchiveRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemUnarchiveRequestBuilder when successful
type ItemWorkflowStatusRequestBuilder ¶
type ItemWorkflowStatusRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemWorkflowStatusRequestBuilder builds and executes requests for operations under \leads\{-id}\workflow-status
func NewItemWorkflowStatusRequestBuilder ¶
func NewItemWorkflowStatusRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemWorkflowStatusRequestBuilder
NewItemWorkflowStatusRequestBuilder instantiates a new ItemWorkflowStatusRequestBuilder and sets the default values.
func NewItemWorkflowStatusRequestBuilderInternal ¶
func NewItemWorkflowStatusRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemWorkflowStatusRequestBuilder
NewItemWorkflowStatusRequestBuilderInternal instantiates a new ItemWorkflowStatusRequestBuilder and sets the default values.
func (*ItemWorkflowStatusRequestBuilder) Get ¶
func (m *ItemWorkflowStatusRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.AutomationWorkflowStatusResponseable, error)
Get returns automation workflow status for one lead, including active runs, paused state, and follow-up progress for the current organization. returns a AutomationWorkflowStatusResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemWorkflowStatusRequestBuilder) ToGetRequestInformation ¶
func (m *ItemWorkflowStatusRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns automation workflow status for one lead, including active runs, paused state, and follow-up progress for the current organization. returns a *RequestInformation when successful
func (*ItemWorkflowStatusRequestBuilder) WithUrl ¶
func (m *ItemWorkflowStatusRequestBuilder) WithUrl(rawUrl string) *ItemWorkflowStatusRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemWorkflowStatusRequestBuilder when successful
type LeadsRequestBuilder ¶
type LeadsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
LeadsRequestBuilder builds and executes requests for operations under \leads
func NewLeadsRequestBuilder ¶
func NewLeadsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *LeadsRequestBuilder
NewLeadsRequestBuilder instantiates a new LeadsRequestBuilder and sets the default values.
func NewLeadsRequestBuilderInternal ¶
func NewLeadsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *LeadsRequestBuilder
NewLeadsRequestBuilderInternal instantiates a new LeadsRequestBuilder and sets the default values.
func (*LeadsRequestBuilder) All ¶
func (m *LeadsRequestBuilder) All() *AllRequestBuilder
All the all property returns a *AllRequestBuilder when successful
func (*LeadsRequestBuilder) ById ¶
func (m *LeadsRequestBuilder) ById(id string) *ItemRequestBuilder
ById gets an item from the github.com/leadpingai/leadping-go.leads.item collection returns a *ItemRequestBuilder when successful
func (*LeadsRequestBuilder) Intake ¶
func (m *LeadsRequestBuilder) Intake() *IntakeRequestBuilder
Intake the intake property returns a *IntakeRequestBuilder when successful
func (*LeadsRequestBuilder) Post ¶
func (m *LeadsRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[LeadsRequestBuilderPostQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadResponseable, error)
Post creates a source-authenticated lead captured outside Leadping, starting follow-up, routing, and automation from structured lead data. returns a LeadResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 404 status code
func (*LeadsRequestBuilder) ToPostRequestInformation ¶
func (m *LeadsRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.LeadRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[LeadsRequestBuilderPostQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation creates a source-authenticated lead captured outside Leadping, starting follow-up, routing, and automation from structured lead data. returns a *RequestInformation when successful
func (*LeadsRequestBuilder) WithUrl ¶
func (m *LeadsRequestBuilder) WithUrl(rawUrl string) *LeadsRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *LeadsRequestBuilder when successful
type LeadsRequestBuilderPostQueryParameters ¶
type LeadsRequestBuilderPostQueryParameters struct {
// The Leadping source key supplied as a query string parameter, or omitted when supplied as Authorization: Bearer lp_src_...
SourceKey *string "uriparametername:\"sourceKey\""
}
LeadsRequestBuilderPostQueryParameters creates a source-authenticated lead captured outside Leadping, starting follow-up, routing, and automation from structured lead data.
Source Files
¶
- all_my_request_builder.go
- all_request_builder.go
- intake_request_builder.go
- item_archive_post_request_body.go
- item_archive_request_builder.go
- item_request_builder.go
- item_status_history_export_request_builder.go
- item_status_history_request_builder.go
- item_status_request_builder.go
- item_tags_request_builder.go
- item_tags_with_tag_item_request_builder.go
- item_unarchive_request_builder.go
- item_workflow_status_request_builder.go
- leads_request_builder.go