Documentation
¶
Index ¶
- type AnnouncementsRequestBuilder
- type ItemMarkReadRequestBuilder
- type MarkAllReadRequestBuilder
- type MeRequestBuilder
- type NotificationsItemRequestBuilder
- type NotificationsRequestBuilder
- func (m *NotificationsRequestBuilder) Announcements() *AnnouncementsRequestBuilder
- func (m *NotificationsRequestBuilder) ById(id string) *NotificationsItemRequestBuilder
- func (m *NotificationsRequestBuilder) MarkAllRead() *MarkAllReadRequestBuilder
- func (m *NotificationsRequestBuilder) Me() *MeRequestBuilder
- func (m *NotificationsRequestBuilder) UnreadCount() *UnreadCountRequestBuilder
- type UnreadCountRequestBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AnnouncementsRequestBuilder ¶
type AnnouncementsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AnnouncementsRequestBuilder builds and executes requests for operations under \notifications\announcements
func NewAnnouncementsRequestBuilder ¶
func NewAnnouncementsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AnnouncementsRequestBuilder
NewAnnouncementsRequestBuilder instantiates a new AnnouncementsRequestBuilder and sets the default values.
func NewAnnouncementsRequestBuilderInternal ¶
func NewAnnouncementsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AnnouncementsRequestBuilder
NewAnnouncementsRequestBuilderInternal instantiates a new AnnouncementsRequestBuilder and sets the default values.
func (*AnnouncementsRequestBuilder) Post ¶
func (m *AnnouncementsRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.PagedResultOfNotificationTableRowable, error)
Post lists announcement notifications for the current user with paging and filters for release notes, notices, and operational updates. returns a PagedResultOfNotificationTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 500 status code
func (*AnnouncementsRequestBuilder) ToPostRequestInformation ¶
func (m *AnnouncementsRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation lists announcement notifications for the current user with paging and filters for release notes, notices, and operational updates. returns a *RequestInformation when successful
func (*AnnouncementsRequestBuilder) WithUrl ¶
func (m *AnnouncementsRequestBuilder) WithUrl(rawUrl string) *AnnouncementsRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AnnouncementsRequestBuilder when successful
type ItemMarkReadRequestBuilder ¶
type ItemMarkReadRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemMarkReadRequestBuilder builds and executes requests for operations under \notifications\{id}\mark-read
func NewItemMarkReadRequestBuilder ¶
func NewItemMarkReadRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemMarkReadRequestBuilder
NewItemMarkReadRequestBuilder instantiates a new ItemMarkReadRequestBuilder and sets the default values.
func NewItemMarkReadRequestBuilderInternal ¶
func NewItemMarkReadRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemMarkReadRequestBuilder
NewItemMarkReadRequestBuilderInternal instantiates a new ItemMarkReadRequestBuilder and sets the default values.
func (*ItemMarkReadRequestBuilder) Post ¶
func (m *ItemMarkReadRequestBuilder) Post(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*bool, error)
Post marks one current-user notification as read so it no longer contributes to unread counts or active notification lists. returns a *bool when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 500 status code
func (*ItemMarkReadRequestBuilder) ToPostRequestInformation ¶
func (m *ItemMarkReadRequestBuilder) ToPostRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation marks one current-user notification as read so it no longer contributes to unread counts or active notification lists. returns a *RequestInformation when successful
func (*ItemMarkReadRequestBuilder) WithUrl ¶
func (m *ItemMarkReadRequestBuilder) WithUrl(rawUrl string) *ItemMarkReadRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemMarkReadRequestBuilder when successful
type MarkAllReadRequestBuilder ¶
type MarkAllReadRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
MarkAllReadRequestBuilder builds and executes requests for operations under \notifications\mark-all-read
func NewMarkAllReadRequestBuilder ¶
func NewMarkAllReadRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MarkAllReadRequestBuilder
NewMarkAllReadRequestBuilder instantiates a new MarkAllReadRequestBuilder and sets the default values.
func NewMarkAllReadRequestBuilderInternal ¶
func NewMarkAllReadRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MarkAllReadRequestBuilder
NewMarkAllReadRequestBuilderInternal instantiates a new MarkAllReadRequestBuilder and sets the default values.
func (*MarkAllReadRequestBuilder) Post ¶
func (m *MarkAllReadRequestBuilder) Post(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*int32, error)
Post marks all notifications for the current user as read and returns the number updated for notification center refreshes. returns a *int32 when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 500 status code
func (*MarkAllReadRequestBuilder) ToPostRequestInformation ¶
func (m *MarkAllReadRequestBuilder) ToPostRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation marks all notifications for the current user as read and returns the number updated for notification center refreshes. returns a *RequestInformation when successful
func (*MarkAllReadRequestBuilder) WithUrl ¶
func (m *MarkAllReadRequestBuilder) WithUrl(rawUrl string) *MarkAllReadRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *MarkAllReadRequestBuilder when successful
type MeRequestBuilder ¶
type MeRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
MeRequestBuilder builds and executes requests for operations under \notifications\me
func NewMeRequestBuilder ¶
func NewMeRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MeRequestBuilder
NewMeRequestBuilder instantiates a new MeRequestBuilder and sets the default values.
func NewMeRequestBuilderInternal ¶
func NewMeRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MeRequestBuilder
NewMeRequestBuilderInternal instantiates a new MeRequestBuilder and sets the default values.
func (*MeRequestBuilder) Post ¶
func (m *MeRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.PagedResultOfNotificationTableRowable, error)
Post lists current-user notifications with paging, sorting, and filters for operational alerts, announcements, and follow-up updates. returns a PagedResultOfNotificationTableRowable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 500 status code
func (*MeRequestBuilder) ToPostRequestInformation ¶
func (m *MeRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation lists current-user notifications with paging, sorting, and filters for operational alerts, announcements, and follow-up updates. returns a *RequestInformation when successful
func (*MeRequestBuilder) WithUrl ¶
func (m *MeRequestBuilder) WithUrl(rawUrl string) *MeRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *MeRequestBuilder when successful
type NotificationsItemRequestBuilder ¶
type NotificationsItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
NotificationsItemRequestBuilder builds and executes requests for operations under \notifications\{id}
func NewNotificationsItemRequestBuilder ¶
func NewNotificationsItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *NotificationsItemRequestBuilder
NewNotificationsItemRequestBuilder instantiates a new NotificationsItemRequestBuilder and sets the default values.
func NewNotificationsItemRequestBuilderInternal ¶
func NewNotificationsItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *NotificationsItemRequestBuilder
NewNotificationsItemRequestBuilderInternal instantiates a new NotificationsItemRequestBuilder and sets the default values.
func (*NotificationsItemRequestBuilder) MarkRead ¶
func (m *NotificationsItemRequestBuilder) MarkRead() *ItemMarkReadRequestBuilder
MarkRead the markRead property returns a *ItemMarkReadRequestBuilder when successful
type NotificationsRequestBuilder ¶
type NotificationsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
NotificationsRequestBuilder builds and executes requests for operations under \notifications
func NewNotificationsRequestBuilder ¶
func NewNotificationsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *NotificationsRequestBuilder
NewNotificationsRequestBuilder instantiates a new NotificationsRequestBuilder and sets the default values.
func NewNotificationsRequestBuilderInternal ¶
func NewNotificationsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *NotificationsRequestBuilder
NewNotificationsRequestBuilderInternal instantiates a new NotificationsRequestBuilder and sets the default values.
func (*NotificationsRequestBuilder) Announcements ¶
func (m *NotificationsRequestBuilder) Announcements() *AnnouncementsRequestBuilder
Announcements the announcements property returns a *AnnouncementsRequestBuilder when successful
func (*NotificationsRequestBuilder) ById ¶
func (m *NotificationsRequestBuilder) ById(id string) *NotificationsItemRequestBuilder
ById gets an item from the github.com/leadpingai/leadping-go.notifications.item collection returns a *NotificationsItemRequestBuilder when successful
func (*NotificationsRequestBuilder) MarkAllRead ¶
func (m *NotificationsRequestBuilder) MarkAllRead() *MarkAllReadRequestBuilder
MarkAllRead the markAllRead property returns a *MarkAllReadRequestBuilder when successful
func (*NotificationsRequestBuilder) Me ¶
func (m *NotificationsRequestBuilder) Me() *MeRequestBuilder
Me the me property returns a *MeRequestBuilder when successful
func (*NotificationsRequestBuilder) UnreadCount ¶
func (m *NotificationsRequestBuilder) UnreadCount() *UnreadCountRequestBuilder
UnreadCount the unreadCount property returns a *UnreadCountRequestBuilder when successful
type UnreadCountRequestBuilder ¶
type UnreadCountRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
UnreadCountRequestBuilder builds and executes requests for operations under \notifications\unread-count
func NewUnreadCountRequestBuilder ¶
func NewUnreadCountRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UnreadCountRequestBuilder
NewUnreadCountRequestBuilder instantiates a new UnreadCountRequestBuilder and sets the default values.
func NewUnreadCountRequestBuilderInternal ¶
func NewUnreadCountRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UnreadCountRequestBuilder
NewUnreadCountRequestBuilderInternal instantiates a new UnreadCountRequestBuilder and sets the default values.
func (*UnreadCountRequestBuilder) Get ¶
func (m *UnreadCountRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*int32, error)
Get returns the current user's unread notification count for badge updates and notification center state. returns a *int32 when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 500 status code
func (*UnreadCountRequestBuilder) ToGetRequestInformation ¶
func (m *UnreadCountRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns the current user's unread notification count for badge updates and notification center state. returns a *RequestInformation when successful
func (*UnreadCountRequestBuilder) WithUrl ¶
func (m *UnreadCountRequestBuilder) WithUrl(rawUrl string) *UnreadCountRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *UnreadCountRequestBuilder when successful