Documentation
¶
Index ¶
- type ExportsItemDownloadRequestBuilder
- type ExportsItemDownloadRequestBuilderGetQueryParameters
- type ExportsMyRequestBuilder
- type ExportsRequestBuilder
- type ExportsWithExportItemRequestBuilder
- func (m *ExportsWithExportItemRequestBuilder) Download() *ExportsItemDownloadRequestBuilder
- func (m *ExportsWithExportItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *ExportsWithExportItemRequestBuilder) ToGetRequestInformation(ctx context.Context, ...) (...)
- func (m *ExportsWithExportItemRequestBuilder) WithUrl(rawUrl string) *ExportsWithExportItemRequestBuilder
- type ReportsRequestBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExportsItemDownloadRequestBuilder ¶
type ExportsItemDownloadRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ExportsItemDownloadRequestBuilder builds and executes requests for operations under \reports\exports\{exportId}\download
func NewExportsItemDownloadRequestBuilder ¶
func NewExportsItemDownloadRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsItemDownloadRequestBuilder
NewExportsItemDownloadRequestBuilder instantiates a new ExportsItemDownloadRequestBuilder and sets the default values.
func NewExportsItemDownloadRequestBuilderInternal ¶
func NewExportsItemDownloadRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsItemDownloadRequestBuilder
NewExportsItemDownloadRequestBuilderInternal instantiates a new ExportsItemDownloadRequestBuilder and sets the default values.
func (*ExportsItemDownloadRequestBuilder) Get ¶
func (m *ExportsItemDownloadRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[ExportsItemDownloadRequestBuilderGetQueryParameters]) error
Get validates an export download token and redirects to the generated file when the current-user report is ready. returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 410 status code returns a ProblemDetails error when the service returns a 429 status code
func (*ExportsItemDownloadRequestBuilder) ToGetRequestInformation ¶
func (m *ExportsItemDownloadRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[ExportsItemDownloadRequestBuilderGetQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation validates an export download token and redirects to the generated file when the current-user report is ready. returns a *RequestInformation when successful
func (*ExportsItemDownloadRequestBuilder) WithUrl ¶
func (m *ExportsItemDownloadRequestBuilder) WithUrl(rawUrl string) *ExportsItemDownloadRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ExportsItemDownloadRequestBuilder when successful
type ExportsItemDownloadRequestBuilderGetQueryParameters ¶
type ExportsItemDownloadRequestBuilderGetQueryParameters struct {
// The short-lived download token issued for this export.
Token *string "uriparametername:\"token\""
}
ExportsItemDownloadRequestBuilderGetQueryParameters validates an export download token and redirects to the generated file when the current-user report is ready.
type ExportsMyRequestBuilder ¶
type ExportsMyRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ExportsMyRequestBuilder builds and executes requests for operations under \reports\exports\my
func NewExportsMyRequestBuilder ¶
func NewExportsMyRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsMyRequestBuilder
NewExportsMyRequestBuilder instantiates a new ExportsMyRequestBuilder and sets the default values.
func NewExportsMyRequestBuilderInternal ¶
func NewExportsMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsMyRequestBuilder
NewExportsMyRequestBuilderInternal instantiates a new ExportsMyRequestBuilder and sets the default values.
func (*ExportsMyRequestBuilder) Post ¶
func (m *ExportsMyRequestBuilder) Post(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserDataExportResponseable, error)
Post requests a data export for the current user, starting asynchronous report generation for account, lead, and event records. returns a UserDataExportResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code
func (*ExportsMyRequestBuilder) ToPostRequestInformation ¶
func (m *ExportsMyRequestBuilder) ToPostRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation requests a data export for the current user, starting asynchronous report generation for account, lead, and event records. returns a *RequestInformation when successful
func (*ExportsMyRequestBuilder) WithUrl ¶
func (m *ExportsMyRequestBuilder) WithUrl(rawUrl string) *ExportsMyRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ExportsMyRequestBuilder when successful
type ExportsRequestBuilder ¶
type ExportsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ExportsRequestBuilder builds and executes requests for operations under \reports\exports
func NewExportsRequestBuilder ¶
func NewExportsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsRequestBuilder
NewExportsRequestBuilder instantiates a new ExportsRequestBuilder and sets the default values.
func NewExportsRequestBuilderInternal ¶
func NewExportsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsRequestBuilder
NewExportsRequestBuilderInternal instantiates a new ExportsRequestBuilder and sets the default values.
func (*ExportsRequestBuilder) ByExportId ¶
func (m *ExportsRequestBuilder) ByExportId(exportId string) *ExportsWithExportItemRequestBuilder
ByExportId gets an item from the github.com/leadpingai/leadping-go.reports.exports.item collection returns a *ExportsWithExportItemRequestBuilder when successful
func (*ExportsRequestBuilder) My ¶
func (m *ExportsRequestBuilder) My() *ExportsMyRequestBuilder
My the my property returns a *ExportsMyRequestBuilder when successful
type ExportsWithExportItemRequestBuilder ¶
type ExportsWithExportItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ExportsWithExportItemRequestBuilder builds and executes requests for operations under \reports\exports\{exportId}
func NewExportsWithExportItemRequestBuilder ¶
func NewExportsWithExportItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsWithExportItemRequestBuilder
NewExportsWithExportItemRequestBuilder instantiates a new ExportsWithExportItemRequestBuilder and sets the default values.
func NewExportsWithExportItemRequestBuilderInternal ¶
func NewExportsWithExportItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ExportsWithExportItemRequestBuilder
NewExportsWithExportItemRequestBuilderInternal instantiates a new ExportsWithExportItemRequestBuilder and sets the default values.
func (*ExportsWithExportItemRequestBuilder) Download ¶
func (m *ExportsWithExportItemRequestBuilder) Download() *ExportsItemDownloadRequestBuilder
Download the download property returns a *ExportsItemDownloadRequestBuilder when successful
func (*ExportsWithExportItemRequestBuilder) Get ¶
func (m *ExportsWithExportItemRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserDataExportResponseable, error)
Get returns the status and metadata for one current-user data export, including readiness, expiration, and download availability. returns a UserDataExportResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 403 status code returns a ProblemDetails error when the service returns a 429 status code
func (*ExportsWithExportItemRequestBuilder) ToGetRequestInformation ¶
func (m *ExportsWithExportItemRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns the status and metadata for one current-user data export, including readiness, expiration, and download availability. returns a *RequestInformation when successful
func (*ExportsWithExportItemRequestBuilder) WithUrl ¶
func (m *ExportsWithExportItemRequestBuilder) WithUrl(rawUrl string) *ExportsWithExportItemRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ExportsWithExportItemRequestBuilder when successful
type ReportsRequestBuilder ¶
type ReportsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ReportsRequestBuilder builds and executes requests for operations under \reports
func NewReportsRequestBuilder ¶
func NewReportsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ReportsRequestBuilder
NewReportsRequestBuilder instantiates a new ReportsRequestBuilder and sets the default values.
func NewReportsRequestBuilderInternal ¶
func NewReportsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ReportsRequestBuilder
NewReportsRequestBuilderInternal instantiates a new ReportsRequestBuilder and sets the default values.
func (*ReportsRequestBuilder) Exports ¶
func (m *ReportsRequestBuilder) Exports() *ExportsRequestBuilder
Exports the exports property returns a *ExportsRequestBuilder when successful