Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ItemCancelRequestBuilder ¶
type ItemCancelRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ItemCancelRequestBuilder builds and executes requests for operations under \sms\{smsEventId}\cancel
func NewItemCancelRequestBuilder ¶
func NewItemCancelRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemCancelRequestBuilder
NewItemCancelRequestBuilder instantiates a new ItemCancelRequestBuilder and sets the default values.
func NewItemCancelRequestBuilderInternal ¶
func NewItemCancelRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ItemCancelRequestBuilder
NewItemCancelRequestBuilderInternal instantiates a new ItemCancelRequestBuilder and sets the default values.
func (*ItemCancelRequestBuilder) Post ¶
func (m *ItemCancelRequestBuilder) Post(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SmsResponseable, error)
Post cancels a scheduled SMS event before delivery, preserving the event record while preventing the queued message from being sent. returns a SmsResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*ItemCancelRequestBuilder) ToPostRequestInformation ¶
func (m *ItemCancelRequestBuilder) ToPostRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation cancels a scheduled SMS event before delivery, preserving the event record while preventing the queued message from being sent. returns a *RequestInformation when successful
func (*ItemCancelRequestBuilder) WithUrl ¶
func (m *ItemCancelRequestBuilder) WithUrl(rawUrl string) *ItemCancelRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ItemCancelRequestBuilder when successful
type SendRequestBuilder ¶
type SendRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
SendRequestBuilder builds and executes requests for operations under \sms\send
func NewSendRequestBuilder ¶
func NewSendRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SendRequestBuilder
NewSendRequestBuilder instantiates a new SendRequestBuilder and sets the default values.
func NewSendRequestBuilderInternal ¶
func NewSendRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SendRequestBuilder
NewSendRequestBuilderInternal instantiates a new SendRequestBuilder and sets the default values.
func (*SendRequestBuilder) Post ¶
func (m *SendRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SendSmsRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SmsResponseable, error)
Post sends an SMS message to a lead or phone number, applying current-business sender selection, scheduling, and delivery rules. returns a SmsResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 500 status code
func (*SendRequestBuilder) ToPostRequestInformation ¶
func (m *SendRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SendSmsRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation sends an SMS message to a lead or phone number, applying current-business sender selection, scheduling, and delivery rules. returns a *RequestInformation when successful
func (*SendRequestBuilder) WithUrl ¶
func (m *SendRequestBuilder) WithUrl(rawUrl string) *SendRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SendRequestBuilder when successful
type SmsRequestBuilder ¶
type SmsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
SmsRequestBuilder builds and executes requests for operations under \sms
func NewSmsRequestBuilder ¶
func NewSmsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsRequestBuilder
NewSmsRequestBuilder instantiates a new SmsRequestBuilder and sets the default values.
func NewSmsRequestBuilderInternal ¶
func NewSmsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SmsRequestBuilder
NewSmsRequestBuilderInternal instantiates a new SmsRequestBuilder and sets the default values.
func (*SmsRequestBuilder) BySmsEventId ¶
func (m *SmsRequestBuilder) BySmsEventId(smsEventId string) *WithSmsEventItemRequestBuilder
BySmsEventId gets an item from the github.com/leadpingai/leadping-go.sms.item collection returns a *WithSmsEventItemRequestBuilder when successful
func (*SmsRequestBuilder) Send ¶
func (m *SmsRequestBuilder) Send() *SendRequestBuilder
Send the send property returns a *SendRequestBuilder when successful
type WithSmsEventItemRequestBuilder ¶
type WithSmsEventItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
WithSmsEventItemRequestBuilder builds and executes requests for operations under \sms\{smsEventId}
func NewWithSmsEventItemRequestBuilder ¶
func NewWithSmsEventItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *WithSmsEventItemRequestBuilder
NewWithSmsEventItemRequestBuilder instantiates a new WithSmsEventItemRequestBuilder and sets the default values.
func NewWithSmsEventItemRequestBuilderInternal ¶
func NewWithSmsEventItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *WithSmsEventItemRequestBuilder
NewWithSmsEventItemRequestBuilderInternal instantiates a new WithSmsEventItemRequestBuilder and sets the default values.
func (*WithSmsEventItemRequestBuilder) Cancel ¶
func (m *WithSmsEventItemRequestBuilder) Cancel() *ItemCancelRequestBuilder
Cancel the cancel property returns a *ItemCancelRequestBuilder when successful