Documentation
¶
Index ¶
- type AllMyRequestBuilder
- type AllRequestBuilder
- type CheckRequestBuilder
- type ReleaseRequestBuilder
- type SuppressionsItemRequestBuilder
- type SuppressionsRequestBuilder
- func (m *SuppressionsRequestBuilder) All() *AllRequestBuilder
- func (m *SuppressionsRequestBuilder) ById(id string) *SuppressionsItemRequestBuilder
- func (m *SuppressionsRequestBuilder) Check() *CheckRequestBuilder
- func (m *SuppressionsRequestBuilder) Post(ctx context.Context, ...) (...)
- func (m *SuppressionsRequestBuilder) Release() *ReleaseRequestBuilder
- func (m *SuppressionsRequestBuilder) ToPostRequestInformation(ctx context.Context, ...) (...)
- func (m *SuppressionsRequestBuilder) WithUrl(rawUrl string) *SuppressionsRequestBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllMyRequestBuilder ¶ added in v1.0.28
type AllMyRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllMyRequestBuilder builds and executes requests for operations under \suppressions\all\my
func NewAllMyRequestBuilder ¶ added in v1.0.28
func NewAllMyRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.
func NewAllMyRequestBuilderInternal ¶ added in v1.0.28
func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.
func (*AllMyRequestBuilder) Post ¶ added in v1.0.28
func (m *AllMyRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.PagedResultOfSuppressionEntryResponseable, error)
Post returns a filtered, paginated list of recipients the current organization has blocked from phone, SMS, or email outreach. returns a PagedResultOfSuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 401 status code
func (*AllMyRequestBuilder) ToPostRequestInformation ¶ added in v1.0.28
func (m *AllMyRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation returns a filtered, paginated list of recipients the current organization has blocked from phone, SMS, or email outreach. returns a *RequestInformation when successful
func (*AllMyRequestBuilder) WithUrl ¶ added in v1.0.28
func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful
type AllRequestBuilder ¶ added in v1.0.28
type AllRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllRequestBuilder builds and executes requests for operations under \suppressions\all
func NewAllRequestBuilder ¶ added in v1.0.28
func NewAllRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.
func NewAllRequestBuilderInternal ¶ added in v1.0.28
func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.
func (*AllRequestBuilder) My ¶ added in v1.0.28
func (m *AllRequestBuilder) My() *AllMyRequestBuilder
My the my property returns a *AllMyRequestBuilder when successful
type CheckRequestBuilder ¶
type CheckRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
CheckRequestBuilder builds and executes requests for operations under \suppressions\check
func NewCheckRequestBuilder ¶
func NewCheckRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CheckRequestBuilder
NewCheckRequestBuilder instantiates a new CheckRequestBuilder and sets the default values.
func NewCheckRequestBuilderInternal ¶
func NewCheckRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *CheckRequestBuilder
NewCheckRequestBuilderInternal instantiates a new CheckRequestBuilder and sets the default values.
func (*CheckRequestBuilder) Post ¶
func (m *CheckRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionCheckResultable, error)
Post checks whether a recipient is blocked by an active Leadping suppression entry before sending messages or placing calls through the selected channel. returns a SuppressionCheckResultable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code
func (*CheckRequestBuilder) ToPostRequestInformation ¶
func (m *CheckRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation checks whether a recipient is blocked by an active Leadping suppression entry before sending messages or placing calls through the selected channel. returns a *RequestInformation when successful
func (*CheckRequestBuilder) WithUrl ¶
func (m *CheckRequestBuilder) WithUrl(rawUrl string) *CheckRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *CheckRequestBuilder when successful
type ReleaseRequestBuilder ¶
type ReleaseRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ReleaseRequestBuilder builds and executes requests for operations under \suppressions\release
func NewReleaseRequestBuilder ¶
func NewReleaseRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ReleaseRequestBuilder
NewReleaseRequestBuilder instantiates a new ReleaseRequestBuilder and sets the default values.
func NewReleaseRequestBuilderInternal ¶
func NewReleaseRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ReleaseRequestBuilder
NewReleaseRequestBuilderInternal instantiates a new ReleaseRequestBuilder and sets the default values.
func (*ReleaseRequestBuilder) Post ¶
func (m *ReleaseRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryResponseable, error)
Post releases an active Leadping suppression entry so a recipient can be contacted again, returning the updated suppression record when available. returns a SuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code
func (*ReleaseRequestBuilder) ToPostRequestInformation ¶
func (m *ReleaseRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation releases an active Leadping suppression entry so a recipient can be contacted again, returning the updated suppression record when available. returns a *RequestInformation when successful
func (*ReleaseRequestBuilder) WithUrl ¶
func (m *ReleaseRequestBuilder) WithUrl(rawUrl string) *ReleaseRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ReleaseRequestBuilder when successful
type SuppressionsItemRequestBuilder ¶ added in v1.0.28
type SuppressionsItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
SuppressionsItemRequestBuilder builds and executes requests for operations under \suppressions\{id}
func NewSuppressionsItemRequestBuilder ¶ added in v1.0.28
func NewSuppressionsItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SuppressionsItemRequestBuilder
NewSuppressionsItemRequestBuilder instantiates a new SuppressionsItemRequestBuilder and sets the default values.
func NewSuppressionsItemRequestBuilderInternal ¶ added in v1.0.28
func NewSuppressionsItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SuppressionsItemRequestBuilder
NewSuppressionsItemRequestBuilderInternal instantiates a new SuppressionsItemRequestBuilder and sets the default values.
func (*SuppressionsItemRequestBuilder) Get ¶ added in v1.0.28
func (m *SuppressionsItemRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryResponseable, error)
Get returns one suppression entry for the current organization, including its recipient, channel, reason, status, and audit timestamps. returns a SuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*SuppressionsItemRequestBuilder) ToGetRequestInformation ¶ added in v1.0.28
func (m *SuppressionsItemRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns one suppression entry for the current organization, including its recipient, channel, reason, status, and audit timestamps. returns a *RequestInformation when successful
func (*SuppressionsItemRequestBuilder) WithUrl ¶ added in v1.0.28
func (m *SuppressionsItemRequestBuilder) WithUrl(rawUrl string) *SuppressionsItemRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SuppressionsItemRequestBuilder when successful
type SuppressionsRequestBuilder ¶
type SuppressionsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
SuppressionsRequestBuilder builds and executes requests for operations under \suppressions
func NewSuppressionsRequestBuilder ¶
func NewSuppressionsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SuppressionsRequestBuilder
NewSuppressionsRequestBuilder instantiates a new SuppressionsRequestBuilder and sets the default values.
func NewSuppressionsRequestBuilderInternal ¶
func NewSuppressionsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SuppressionsRequestBuilder
NewSuppressionsRequestBuilderInternal instantiates a new SuppressionsRequestBuilder and sets the default values.
func (*SuppressionsRequestBuilder) All ¶ added in v1.0.28
func (m *SuppressionsRequestBuilder) All() *AllRequestBuilder
All the all property returns a *AllRequestBuilder when successful
func (*SuppressionsRequestBuilder) ById ¶ added in v1.0.28
func (m *SuppressionsRequestBuilder) ById(id string) *SuppressionsItemRequestBuilder
ById gets an item from the github.com/leadpingai/leadping-go.suppressions.item collection returns a *SuppressionsItemRequestBuilder when successful
func (*SuppressionsRequestBuilder) Check ¶
func (m *SuppressionsRequestBuilder) Check() *CheckRequestBuilder
Check the check property returns a *CheckRequestBuilder when successful
func (*SuppressionsRequestBuilder) Post ¶
func (m *SuppressionsRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryResponseable, error)
Post creates or reactivates a Leadping suppression entry that blocks future outreach to a recipient across the selected communication channel. returns a SuppressionEntryResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code
func (*SuppressionsRequestBuilder) Release ¶
func (m *SuppressionsRequestBuilder) Release() *ReleaseRequestBuilder
Release the release property returns a *ReleaseRequestBuilder when successful
func (*SuppressionsRequestBuilder) ToPostRequestInformation ¶
func (m *SuppressionsRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.SuppressionEntryRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation creates or reactivates a Leadping suppression entry that blocks future outreach to a recipient across the selected communication channel. returns a *RequestInformation when successful
func (*SuppressionsRequestBuilder) WithUrl ¶
func (m *SuppressionsRequestBuilder) WithUrl(rawUrl string) *SuppressionsRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SuppressionsRequestBuilder when successful