Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllMyRequestBuilder ¶
type AllMyRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllMyRequestBuilder builds and executes requests for operations under \transactions\all\my
func NewAllMyRequestBuilder ¶
func NewAllMyRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.
func NewAllMyRequestBuilderInternal ¶
func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder
NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.
func (*AllMyRequestBuilder) Post ¶
func (m *AllMyRequestBuilder) Post(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[AllMyRequestBuilderPostQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.PagedResultOfTransactionTableRowable, error)
Post lists current-user transactions with paging, sorting, and filters for wallet events, billing history, and reconciliation. returns a PagedResultOfTransactionTableRowable when successful returns a ProblemDetails error when the service returns a 401 status code
func (*AllMyRequestBuilder) ToPostRequestInformation ¶
func (m *AllMyRequestBuilder) ToPostRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.RequestDataOptionsable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[AllMyRequestBuilderPostQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPostRequestInformation lists current-user transactions with paging, sorting, and filters for wallet events, billing history, and reconciliation. returns a *RequestInformation when successful
func (*AllMyRequestBuilder) WithUrl ¶
func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful
type AllMyRequestBuilderPostQueryParameters ¶ added in v1.0.12
type AllMyRequestBuilderPostQueryParameters struct {
EndAt *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"endAt\""
StartAt *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"startAt\""
}
AllMyRequestBuilderPostQueryParameters lists current-user transactions with paging, sorting, and filters for wallet events, billing history, and reconciliation.
type AllRequestBuilder ¶
type AllRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
AllRequestBuilder builds and executes requests for operations under \transactions\all
func NewAllRequestBuilder ¶
func NewAllRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.
func NewAllRequestBuilderInternal ¶
func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder
NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.
func (*AllRequestBuilder) My ¶
func (m *AllRequestBuilder) My() *AllMyRequestBuilder
My the my property returns a *AllMyRequestBuilder when successful
type TransactionsItemRequestBuilder ¶
type TransactionsItemRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
TransactionsItemRequestBuilder builds and executes requests for operations under \transactions\{id}
func NewTransactionsItemRequestBuilder ¶
func NewTransactionsItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *TransactionsItemRequestBuilder
NewTransactionsItemRequestBuilder instantiates a new TransactionsItemRequestBuilder and sets the default values.
func NewTransactionsItemRequestBuilderInternal ¶
func NewTransactionsItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *TransactionsItemRequestBuilder
NewTransactionsItemRequestBuilderInternal instantiates a new TransactionsItemRequestBuilder and sets the default values.
func (*TransactionsItemRequestBuilder) Get ¶
func (m *TransactionsItemRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.TransactionResponseable, error)
Get returns one transaction visible to the current user, including amount, status, wallet context, and billing metadata. returns a TransactionResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code
func (*TransactionsItemRequestBuilder) ToGetRequestInformation ¶
func (m *TransactionsItemRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns one transaction visible to the current user, including amount, status, wallet context, and billing metadata. returns a *RequestInformation when successful
func (*TransactionsItemRequestBuilder) WithUrl ¶
func (m *TransactionsItemRequestBuilder) WithUrl(rawUrl string) *TransactionsItemRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *TransactionsItemRequestBuilder when successful
type TransactionsRequestBuilder ¶
type TransactionsRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
TransactionsRequestBuilder builds and executes requests for operations under \transactions
func NewTransactionsRequestBuilder ¶
func NewTransactionsRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *TransactionsRequestBuilder
NewTransactionsRequestBuilder instantiates a new TransactionsRequestBuilder and sets the default values.
func NewTransactionsRequestBuilderInternal ¶
func NewTransactionsRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *TransactionsRequestBuilder
NewTransactionsRequestBuilderInternal instantiates a new TransactionsRequestBuilder and sets the default values.
func (*TransactionsRequestBuilder) All ¶
func (m *TransactionsRequestBuilder) All() *AllRequestBuilder
All the all property returns a *AllRequestBuilder when successful
func (*TransactionsRequestBuilder) ById ¶
func (m *TransactionsRequestBuilder) ById(id string) *TransactionsItemRequestBuilder
ById gets an item from the github.com/leadpingai/leadping-go.transactions.item collection returns a *TransactionsItemRequestBuilder when successful