usage

package
v1.0.31 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AllMyRequestBuilder

AllMyRequestBuilder builds and executes requests for operations under \usage\all\my

func NewAllMyRequestBuilder

NewAllMyRequestBuilder instantiates a new AllMyRequestBuilder and sets the default values.

func NewAllMyRequestBuilderInternal

func NewAllMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllMyRequestBuilder

NewAllMyRequestBuilderInternal instantiates a new AllMyRequestBuilder and sets the default values.

func (*AllMyRequestBuilder) Post

Post lists current-organization usage ledger entries with paging, sorting, and filters for messaging, billing, and wallet review. returns a PagedResultOfUsageLedgerTableRowable when successful returns a ProblemDetails error when the service returns a 401 status code

func (*AllMyRequestBuilder) ToPostRequestInformation

ToPostRequestInformation lists current-organization usage ledger entries with paging, sorting, and filters for messaging, billing, and wallet review. returns a *RequestInformation when successful

func (*AllMyRequestBuilder) WithUrl

func (m *AllMyRequestBuilder) WithUrl(rawUrl string) *AllMyRequestBuilder

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *AllMyRequestBuilder when successful

type AllRequestBuilder

AllRequestBuilder builds and executes requests for operations under \usage\all

func NewAllRequestBuilder

NewAllRequestBuilder instantiates a new AllRequestBuilder and sets the default values.

func NewAllRequestBuilderInternal

func NewAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AllRequestBuilder

NewAllRequestBuilderInternal instantiates a new AllRequestBuilder and sets the default values.

func (*AllRequestBuilder) My

My the my property returns a *AllMyRequestBuilder when successful

type SummaryMyRequestBuilder

SummaryMyRequestBuilder builds and executes requests for operations under \usage\summary\my

func NewSummaryMyRequestBuilder

NewSummaryMyRequestBuilder instantiates a new SummaryMyRequestBuilder and sets the default values.

func NewSummaryMyRequestBuilderInternal

func NewSummaryMyRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SummaryMyRequestBuilder

NewSummaryMyRequestBuilderInternal instantiates a new SummaryMyRequestBuilder and sets the default values.

func (*SummaryMyRequestBuilder) Get

Get returns current-organization usage totals for the active billing period, including spend, limits, and event summary data. returns a UsageSummaryResponseable when successful returns a ProblemDetails error when the service returns a 401 status code

func (*SummaryMyRequestBuilder) ToGetRequestInformation

ToGetRequestInformation returns current-organization usage totals for the active billing period, including spend, limits, and event summary data. returns a *RequestInformation when successful

func (*SummaryMyRequestBuilder) WithUrl

WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *SummaryMyRequestBuilder when successful

type SummaryMyRequestBuilderGetQueryParameters

type SummaryMyRequestBuilderGetQueryParameters struct {
	// The period end.
	PeriodEnd *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"periodEnd\""
	// The period start.
	PeriodStart *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time "uriparametername:\"periodStart\""
}

SummaryMyRequestBuilderGetQueryParameters returns current-organization usage totals for the active billing period, including spend, limits, and event summary data.

type SummaryRequestBuilder

SummaryRequestBuilder builds and executes requests for operations under \usage\summary

func NewSummaryRequestBuilder

NewSummaryRequestBuilder instantiates a new SummaryRequestBuilder and sets the default values.

func NewSummaryRequestBuilderInternal

func NewSummaryRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *SummaryRequestBuilder

NewSummaryRequestBuilderInternal instantiates a new SummaryRequestBuilder and sets the default values.

func (*SummaryRequestBuilder) My

My the my property returns a *SummaryMyRequestBuilder when successful

type UsageRequestBuilder

UsageRequestBuilder builds and executes requests for operations under \usage

func NewUsageRequestBuilder

NewUsageRequestBuilder instantiates a new UsageRequestBuilder and sets the default values.

func NewUsageRequestBuilderInternal

func NewUsageRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UsageRequestBuilder

NewUsageRequestBuilderInternal instantiates a new UsageRequestBuilder and sets the default values.

func (*UsageRequestBuilder) All

All the all property returns a *AllRequestBuilder when successful

func (*UsageRequestBuilder) Summary

Summary the summary property returns a *SummaryRequestBuilder when successful

Jump to