Documentation
¶
Index ¶
- type ChangeBillingPlanRequestBuilder
- type ComplianceRequestBuilder
- type MePaymentmethodRequestBuilder
- type MeRequestBuilder
- func (m *MeRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *MeRequestBuilder) Paymentmethod() *MePaymentmethodRequestBuilder
- func (m *MeRequestBuilder) Put(ctx context.Context, ...) (...)
- func (m *MeRequestBuilder) ToGetRequestInformation(ctx context.Context, ...) (...)
- func (m *MeRequestBuilder) ToPutRequestInformation(ctx context.Context, ...) (...)
- func (m *MeRequestBuilder) WithUrl(rawUrl string) *MeRequestBuilder
- type UsersRequestBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChangeBillingPlanRequestBuilder ¶
type ChangeBillingPlanRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ChangeBillingPlanRequestBuilder builds and executes requests for operations under \users\change-billing-plan
func NewChangeBillingPlanRequestBuilder ¶
func NewChangeBillingPlanRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ChangeBillingPlanRequestBuilder
NewChangeBillingPlanRequestBuilder instantiates a new ChangeBillingPlanRequestBuilder and sets the default values.
func NewChangeBillingPlanRequestBuilderInternal ¶
func NewChangeBillingPlanRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ChangeBillingPlanRequestBuilder
NewChangeBillingPlanRequestBuilderInternal instantiates a new ChangeBillingPlanRequestBuilder and sets the default values.
func (*ChangeBillingPlanRequestBuilder) Put ¶
func (m *ChangeBillingPlanRequestBuilder) Put(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.ChangeBillingPlanRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserResponseable, error)
Put changes the current user's billing plan selection, updating account billing state and plan-specific capabilities. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code
func (*ChangeBillingPlanRequestBuilder) ToPutRequestInformation ¶
func (m *ChangeBillingPlanRequestBuilder) ToPutRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.ChangeBillingPlanRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPutRequestInformation changes the current user's billing plan selection, updating account billing state and plan-specific capabilities. returns a *RequestInformation when successful
func (*ChangeBillingPlanRequestBuilder) WithUrl ¶
func (m *ChangeBillingPlanRequestBuilder) WithUrl(rawUrl string) *ChangeBillingPlanRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ChangeBillingPlanRequestBuilder when successful
type ComplianceRequestBuilder ¶
type ComplianceRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
ComplianceRequestBuilder builds and executes requests for operations under \users\compliance
func NewComplianceRequestBuilder ¶
func NewComplianceRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ComplianceRequestBuilder
NewComplianceRequestBuilder instantiates a new ComplianceRequestBuilder and sets the default values.
func NewComplianceRequestBuilderInternal ¶
func NewComplianceRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ComplianceRequestBuilder
NewComplianceRequestBuilderInternal instantiates a new ComplianceRequestBuilder and sets the default values.
func (*ComplianceRequestBuilder) Put ¶
func (m *ComplianceRequestBuilder) Put(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.ComplianceUpdateRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserResponseable, error)
Put updates current-user compliance settings used for messaging eligibility, billing readiness, and organization account setup. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 429 status code
func (*ComplianceRequestBuilder) ToPutRequestInformation ¶
func (m *ComplianceRequestBuilder) ToPutRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.ComplianceUpdateRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPutRequestInformation updates current-user compliance settings used for messaging eligibility, billing readiness, and organization account setup. returns a *RequestInformation when successful
func (*ComplianceRequestBuilder) WithUrl ¶
func (m *ComplianceRequestBuilder) WithUrl(rawUrl string) *ComplianceRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *ComplianceRequestBuilder when successful
type MePaymentmethodRequestBuilder ¶
type MePaymentmethodRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
MePaymentmethodRequestBuilder builds and executes requests for operations under \users\me\paymentmethod
func NewMePaymentmethodRequestBuilder ¶
func NewMePaymentmethodRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MePaymentmethodRequestBuilder
NewMePaymentmethodRequestBuilder instantiates a new MePaymentmethodRequestBuilder and sets the default values.
func NewMePaymentmethodRequestBuilderInternal ¶
func NewMePaymentmethodRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MePaymentmethodRequestBuilder
NewMePaymentmethodRequestBuilderInternal instantiates a new MePaymentmethodRequestBuilder and sets the default values.
func (*MePaymentmethodRequestBuilder) Get ¶
func (m *MePaymentmethodRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.StripePaymentMethodResponseable, error)
Get returns the current user's default payment method details for billing displays and account payment management. returns a StripePaymentMethodResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 429 status code
func (*MePaymentmethodRequestBuilder) ToGetRequestInformation ¶
func (m *MePaymentmethodRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns the current user's default payment method details for billing displays and account payment management. returns a *RequestInformation when successful
func (*MePaymentmethodRequestBuilder) WithUrl ¶
func (m *MePaymentmethodRequestBuilder) WithUrl(rawUrl string) *MePaymentmethodRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *MePaymentmethodRequestBuilder when successful
type MeRequestBuilder ¶
type MeRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
MeRequestBuilder builds and executes requests for operations under \users\me
func NewMeRequestBuilder ¶
func NewMeRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MeRequestBuilder
NewMeRequestBuilder instantiates a new MeRequestBuilder and sets the default values.
func NewMeRequestBuilderInternal ¶
func NewMeRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MeRequestBuilder
NewMeRequestBuilderInternal instantiates a new MeRequestBuilder and sets the default values.
func (*MeRequestBuilder) Get ¶
func (m *MeRequestBuilder) Get(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserResponseable, error)
Get returns the current user's profile, roles, organization context, billing state, and compliance settings for portal sessions. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 404 status code returns a ProblemDetails error when the service returns a 429 status code
func (*MeRequestBuilder) Paymentmethod ¶
func (m *MeRequestBuilder) Paymentmethod() *MePaymentmethodRequestBuilder
Paymentmethod the paymentmethod property returns a *MePaymentmethodRequestBuilder when successful
func (*MeRequestBuilder) Put ¶
func (m *MeRequestBuilder) Put(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserResponseable, error)
Put updates the current user's profile fields, contact details, preferences, or organization context used across Leadping. returns a UserResponseable when successful returns a ProblemDetails error when the service returns a 400 status code returns a ProblemDetails error when the service returns a 401 status code returns a ProblemDetails error when the service returns a 429 status code
func (*MeRequestBuilder) ToGetRequestInformation ¶
func (m *MeRequestBuilder) ToGetRequestInformation(ctx context.Context, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToGetRequestInformation returns the current user's profile, roles, organization context, billing state, and compliance settings for portal sessions. returns a *RequestInformation when successful
func (*MeRequestBuilder) ToPutRequestInformation ¶
func (m *MeRequestBuilder) ToPutRequestInformation(ctx context.Context, body i01c1fcf104a8c6ee60f7ac9622055caa34c4bc3debe751d81944bd1693855811.UserRequestable, requestConfiguration *i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestConfiguration[i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.DefaultQueryParameters]) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
ToPutRequestInformation updates the current user's profile fields, contact details, preferences, or organization context used across Leadping. returns a *RequestInformation when successful
func (*MeRequestBuilder) WithUrl ¶
func (m *MeRequestBuilder) WithUrl(rawUrl string) *MeRequestBuilder
WithUrl returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored. returns a *MeRequestBuilder when successful
type UsersRequestBuilder ¶
type UsersRequestBuilder struct {
i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.BaseRequestBuilder
}
UsersRequestBuilder builds and executes requests for operations under \users
func NewUsersRequestBuilder ¶
func NewUsersRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UsersRequestBuilder
NewUsersRequestBuilder instantiates a new UsersRequestBuilder and sets the default values.
func NewUsersRequestBuilderInternal ¶
func NewUsersRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *UsersRequestBuilder
NewUsersRequestBuilderInternal instantiates a new UsersRequestBuilder and sets the default values.
func (*UsersRequestBuilder) ChangeBillingPlan ¶
func (m *UsersRequestBuilder) ChangeBillingPlan() *ChangeBillingPlanRequestBuilder
ChangeBillingPlan the changeBillingPlan property returns a *ChangeBillingPlanRequestBuilder when successful
func (*UsersRequestBuilder) Compliance ¶
func (m *UsersRequestBuilder) Compliance() *ComplianceRequestBuilder
Compliance the compliance property returns a *ComplianceRequestBuilder when successful
func (*UsersRequestBuilder) Me ¶
func (m *UsersRequestBuilder) Me() *MeRequestBuilder
Me the me property returns a *MeRequestBuilder when successful